@@ -7,23 +7,16 @@ from collections import OrderedDict, defaultdict
 import cloudpickle
 import numpy as np
 import pandas as pd
-import woodwork as ww
-from sklearn.model_selection import (
-    BaseCrossValidator,
-    KFold,
-    StratifiedKFold,
-    train_test_split
-)
+from sklearn.model_selection import BaseCrossValidator
 
 from .pipeline_search_plots import PipelineSearchPlots
 
 from evalml.automl.automl_algorithm import IterativeAlgorithm
 from evalml.automl.callbacks import log_error_callback
-from evalml.automl.data_splitters import (
-    TimeSeriesSplit,
-    TrainingValidationSplit
+from evalml.automl.utils import (
+    get_default_primary_search_objective,
+    make_data_splitter
 )
-from evalml.automl.utils import get_default_primary_search_objective
 from evalml.data_checks import (
     AutoMLDataChecks,
     DataChecks,
@@ -47,13 +40,16 @@ from evalml.pipelines import (
     BinaryClassificationPipeline,
     MeanBaselineRegressionPipeline,
     ModeBaselineBinaryPipeline,
-    ModeBaselineMulticlassPipeline
+    ModeBaselineMulticlassPipeline,
+    PipelineBase,
+    TimeSeriesBaselineRegressionPipeline
 )
 from evalml.pipelines.components.utils import get_estimators
 from evalml.pipelines.utils import make_pipeline
+from evalml.preprocessing import split_data
 from evalml.problem_types import ProblemTypes, handle_problem_types
 from evalml.tuners import SKOptTuner
-from evalml.utils import convert_to_seconds, get_random_state
+from evalml.utils import convert_to_seconds, get_random_seed, get_random_state
 from evalml.utils.gen_utils import (
     _convert_to_woodwork_structure,
     _convert_woodwork_types_wrapper
@@ -72,20 +68,20 @@ logger = get_logger(__file__)
 class AutoMLSearch:
     """Automated Pipeline search."""
     _MAX_NAME_LEN = 40
-    _LARGE_DATA_ROW_THRESHOLD = int(1e5)
-    _LARGE_DATA_PERCENT_VALIDATION = 0.75
 
     # Necessary for "Plotting" documentation, since Sphinx does not work well with instance attributes.
     plot = PipelineSearchPlots
 
     def __init__(self,
+                 X_train=None,
+                 y_train=None,
                  problem_type=None,
                  objective='auto',
                  max_iterations=None,
                  max_time=None,
                  patience=None,
                  tolerance=None,
-                 data_split=None,
+                 data_splitter=None,
                  allowed_pipelines=None,
                  allowed_model_families=None,
                  start_iteration_callback=None,
@@ -100,11 +96,16 @@ class AutoMLSearch:
                  ensembling=False,
                  max_batches=None,
                  problem_configuration=None,
+                 train_best_pipeline=True,
                  _pipelines_per_batch=5):
         """Automated pipeline search
 
         Arguments:
-            problem_type (str or ProblemTypes): Choice of 'regression', 'binary', or 'multiclass', depending on the desired problem type.
+            X_train (pd.DataFrame, ww.DataTable): The input training data of shape [n_samples, n_features]. Required.
+
+            y_train (pd.Series, ww.DataColumn): The target training data of length [n_samples]. Required for supervised learning tasks.
+
+            problem_type (str or ProblemTypes): type of supervised learning problem. See evalml.problem_types.ProblemType.all_problem_types for a full list.
 
             objective (str, ObjectiveBase): The objective to optimize for. Used to propose and rank pipelines, but not for optimizing each pipeline during fit-time.
                 When set to 'auto', chooses:
@@ -136,7 +137,7 @@ class AutoMLSearch:
                 to `multiclass` or `regression` depending on the problem type. Note that if allowed_pipelines is provided,
                 this parameter will be ignored.
 
-            data_split (sklearn.model_selection.BaseCrossValidator): Data splitting method to use. Defaults to StratifiedKFold.
+            data_splitter (sklearn.model_selection.BaseCrossValidator): Data splitting method to use. Defaults to StratifiedKFold.
 
             tuner_class: The tuner class to use. Defaults to SKOptTuner.
 
@@ -170,9 +171,15 @@ class AutoMLSearch:
             problem_configuration (dict, None): Additional parameters needed to configure the search. For example,
                 in time series problems, values should be passed in for the gap and max_delay variables.
 
+            train_best_pipeline (boolean): Whether or not to train the best pipeline before returning it. Defaults to True
+
             _pipelines_per_batch (int): The number of pipelines to train for every batch after the first one.
                 The first batch will train a baseline pipline + one of each pipeline family allowed in the search.
         """
+        if X_train is None:
+            raise ValueError('Must specify training data as a 2d array using the X_train argument')
+        if y_train is None:
+            raise ValueError('Must specify training data target values as a 1d vector using the y_train argument')
         try:
             self.problem_type = handle_problem_types(problem_type)
         except ValueError:
@@ -182,7 +189,7 @@ class AutoMLSearch:
         self.start_iteration_callback = start_iteration_callback
         self.add_result_callback = add_result_callback
         self.error_callback = error_callback or log_error_callback
-        self.data_split = data_split
+        self.data_splitter = data_splitter
         self.verbose = verbose
         self.optimize_thresholds = optimize_thresholds
         self.ensembling = ensembling
@@ -190,7 +197,7 @@ class AutoMLSearch:
             objective = get_default_primary_search_objective(self.problem_type.value)
         objective = get_objective(objective, return_instance=False)
         self.objective = self._validate_objective(objective)
-        if self.data_split is not None and not issubclass(self.data_split.__class__, BaseCrossValidator):
+        if self.data_splitter is not None and not issubclass(self.data_splitter.__class__, BaseCrossValidator):
             raise ValueError("Not a valid data splitter")
         if not objective.is_defined_for_problem_type(self.problem_type):
             raise ValueError("Given objective {} is not compatible with a {} problem.".format(self.objective.name, self.problem_type.value))
@@ -235,6 +242,7 @@ class AutoMLSearch:
             'errors': []
         }
         self.random_state = get_random_state(random_state)
+        self.random_seed = get_random_seed(self.random_state)
         self.n_jobs = n_jobs
 
         self.plot = None
@@ -250,9 +258,20 @@ class AutoMLSearch:
         self._automl_algorithm = None
         self._start = None
         self._baseline_cv_scores = {}
+        self.show_batch_output = False
 
         self._validate_problem_type()
         self.problem_configuration = self._validate_problem_configuration(problem_configuration)
+        self._train_best_pipeline = train_best_pipeline
+        self._best_pipeline = None
+
+        # make everything ww objects
+        self.X_train = _convert_to_woodwork_structure(X_train)
+        self.y_train = _convert_to_woodwork_structure(y_train)
+
+        default_data_splitter = make_data_splitter(self.X_train, self.y_train, self.problem_type, self.problem_configuration,
+                                                   n_splits=3, shuffle=True, random_state=self.random_seed)
+        self.data_splitter = self.data_splitter or default_data_splitter
 
     def _validate_objective(self, objective):
         non_core_objectives = get_non_core_objectives()
@@ -290,7 +309,7 @@ class AutoMLSearch:
             f"Allowed Pipelines: \n{_print_list(self.allowed_pipelines or [])}\n"
             f"Patience: {self.patience}\n"
             f"Tolerance: {self.tolerance}\n"
-            f"Data Splitting: {self.data_split}\n"
+            f"Data Splitting: {self.data_splitter}\n"
             f"Tuner: {self.tuner_class.__name__}\n"
             f"Start Iteration Callback: {_get_funct_name(self.start_iteration_callback)}\n"
             f"Add Result Callback: {_get_funct_name(self.add_result_callback)}\n"
@@ -369,43 +388,20 @@ class AutoMLSearch:
             else:
                 leading_char = ""
 
-    def _set_data_split(self, X):
-        """Sets the data split method for AutoMLSearch
-
-        Arguments:
-            X (DataFrame): Input dataframe to split
-        """
-        if self.problem_type == ProblemTypes.REGRESSION:
-            default_data_split = KFold(n_splits=3, random_state=self.random_state, shuffle=True)
-        elif self.problem_type in [ProblemTypes.BINARY, ProblemTypes.MULTICLASS]:
-            default_data_split = StratifiedKFold(n_splits=3, random_state=self.random_state, shuffle=True)
-        elif self.problem_type in [ProblemTypes.TIME_SERIES_REGRESSION]:
-            default_data_split = TimeSeriesSplit(n_splits=3, gap=self.problem_configuration['gap'],
-                                                 max_delay=self.problem_configuration['max_delay'])
-
-        if X.shape[0] > self._LARGE_DATA_ROW_THRESHOLD:
-            default_data_split = TrainingValidationSplit(test_size=self._LARGE_DATA_PERCENT_VALIDATION, shuffle=True)
-
-        self.data_split = self.data_split or default_data_split
-
-    def search(self, X, y, data_checks="auto", show_iteration_plot=True):
+    def search(self, data_checks="auto", show_iteration_plot=True):
         """Find the best pipeline for the data set.
 
         Arguments:
-            X (pd.DataFrame, ww.DataTable): The input training data of shape [n_samples, n_features]
+            data_checks (DataChecks, list(Datacheck), str, None): A collection of data checks to run before
+                automl search. If data checks produce any errors, an exception will be thrown before the
+                search begins. If "disabled" or None, `no` data checks will be done.
+                If set to "auto", DefaultDataChecks will be done. Default value is set to "auto".
 
-            y (pd.Series, ww.DataColumn): The target training data of length [n_samples]
+            feature_types (list, optional): list of feature types, either numerical or categorical.
+                Categorical features will automatically be encoded
 
             show_iteration_plot (boolean, True): Shows an iteration vs. score plot in Jupyter notebook.
                 Disabled by default in non-Jupyter enviroments.
-
-            data_checks (DataChecks, list(Datacheck), str, None): A collection of data checks to run before
-                automl search. If data checks produce any errors, an exception will be thrown before the
-                search begins. If "disabled" or None, no data checks will be done.
-                If set to "auto", DefaultDataChecks will be done. Default value is set to "auto".
-
-        Returns:
-            self
         """
         # don't show iteration plot outside of a jupyter notebook
         if show_iteration_plot:
@@ -414,24 +410,14 @@ class AutoMLSearch:
             except NameError:
                 show_iteration_plot = False
 
-        # make everything ww objects
-        if not isinstance(X, ww.DataTable):
-            logger.warning("`X` passed was not a DataTable. EvalML will try to convert the input as a Woodwork DataTable and types will be inferred. To control this behavior, please pass in a Woodwork DataTable instead.")
-            X = _convert_to_woodwork_structure(X)
-
-        text_column_vals = X.select('natural_language')
+        text_column_vals = self.X_train.select('natural_language')
         text_columns = list(text_column_vals.to_dataframe().columns)
         if len(text_columns) == 0:
             text_columns = None
 
-        if not isinstance(y, ww.DataColumn):
-            logger.warning("`y` passed was not a DataColumn. EvalML will try to convert the input as a Woodwork DataTable and types will be inferred. To control this behavior, please pass in a Woodwork DataTable instead.")
-            y = _convert_to_woodwork_structure(y)
-
-        self._set_data_split(X)
-
         data_checks = self._validate_data_checks(data_checks)
-        self._data_check_results = data_checks.validate(_convert_woodwork_types_wrapper(X.to_dataframe()), _convert_woodwork_types_wrapper(y.to_series()))
+        self._data_check_results = data_checks.validate(_convert_woodwork_types_wrapper(self.X_train.to_dataframe()),
+                                                        _convert_woodwork_types_wrapper(self.y_train.to_series()))
         for message in self._data_check_results["warnings"]:
             logger.warning(message)
         for message in self._data_check_results["errors"]:
@@ -442,20 +428,35 @@ class AutoMLSearch:
             logger.info("Generating pipelines to search over...")
             allowed_estimators = get_estimators(self.problem_type, self.allowed_model_families)
             logger.debug(f"allowed_estimators set to {[estimator.name for estimator in allowed_estimators]}")
-            self.allowed_pipelines = [make_pipeline(X, y, estimator, self.problem_type, text_columns=text_columns) for estimator in allowed_estimators]
+            self.allowed_pipelines = [make_pipeline(self.X_train, self.y_train, estimator, self.problem_type, text_columns=text_columns) for estimator in allowed_estimators]
 
         if self.allowed_pipelines == []:
             raise ValueError("No allowed pipelines to search")
 
         run_ensembling = self.ensembling
         if run_ensembling and len(self.allowed_pipelines) == 1:
-            logger.warning("Ensembling was set to True, but the number of unique pipelines is one, so ensembling will not run.")
+            logger.warning("Ensembling is set to True, but the number of unique pipelines is one, so ensembling will not run.")
             run_ensembling = False
 
+        if run_ensembling and self.max_iterations is not None:
+            # Baseline + first batch + each pipeline iteration + 1
+            first_ensembling_iteration = (1 + len(self.allowed_pipelines) + len(self.allowed_pipelines) * self._pipelines_per_batch + 1)
+            if self.max_iterations < first_ensembling_iteration:
+                run_ensembling = False
+                logger.warning(f"Ensembling is set to True, but max_iterations is too small, so ensembling will not run. Set max_iterations >= {first_ensembling_iteration} to run ensembling.")
+            else:
+                logger.info(f"Ensembling will run at the {first_ensembling_iteration} iteration and every {len(self.allowed_pipelines) * self._pipelines_per_batch} iterations after that.")
+
         if self.max_batches and self.max_iterations is None:
+            self.show_batch_output = True
             if run_ensembling:
                 ensemble_nth_batch = len(self.allowed_pipelines) + 1
                 num_ensemble_batches = (self.max_batches - 1) // ensemble_nth_batch
+                if num_ensemble_batches == 0:
+                    logger.warning(f"Ensembling is set to True, but max_batches is too small, so ensembling will not run. Set max_batches >= {ensemble_nth_batch + 1} to run ensembling.")
+                else:
+                    logger.info(f"Ensembling will run every {ensemble_nth_batch} batches.")
+
                 self.max_iterations = (1 + len(self.allowed_pipelines) +
                                        self._pipelines_per_batch * (self.max_batches - 1 - num_ensemble_batches) +
                                        num_ensemble_batches)
@@ -473,7 +474,7 @@ class AutoMLSearch:
             text_columns=text_columns,
             random_state=self.random_state,
             n_jobs=self.n_jobs,
-            number_features=X.shape[1],
+            number_features=self.X_train.shape[1],
             pipelines_per_batch=self._pipelines_per_batch,
             ensembling=run_ensembling,
             pipeline_params=self.problem_configuration
@@ -496,7 +497,7 @@ class AutoMLSearch:
 
         self._start = time.time()
 
-        should_terminate = self._add_baseline_pipelines(X, y)
+        should_terminate = self._add_baseline_pipelines()
         if should_terminate:
             return
 
@@ -504,45 +505,20 @@ class AutoMLSearch:
         current_batch_pipeline_scores = []
         while self._check_stopping_condition(self._start):
             try:
-                if len(current_batch_pipelines) == 0:
-                    try:
-                        if current_batch_pipeline_scores and np.isnan(np.array(current_batch_pipeline_scores, dtype=float)).all():
-                            raise AutoMLSearchException(f"All pipelines in the current AutoML batch produced a score of np.nan on the primary objective {self.objective}.")
-                        current_batch_pipelines = self._automl_algorithm.next_batch()
-                        current_batch_pipeline_scores = []
-                    except StopIteration:
-                        logger.info('AutoML Algorithm out of recommendations, ending')
-                        break
-                pipeline = current_batch_pipelines.pop(0)
-                parameters = pipeline.parameters
-                logger.debug('Evaluating pipeline {}'.format(pipeline.name))
-                logger.debug('Pipeline parameters: {}'.format(parameters))
+                if current_batch_pipeline_scores and np.isnan(np.array(current_batch_pipeline_scores, dtype=float)).all():
+                    raise AutoMLSearchException(f"All pipelines in the current AutoML batch produced a score of np.nan on the primary objective {self.objective}.")
+                current_batch_pipelines = self._automl_algorithm.next_batch()
+                current_batch_pipeline_scores = []
+            except StopIteration:
+                logger.info('AutoML Algorithm out of recommendations, ending')
+                break
 
-                if self.start_iteration_callback:
-                    self.start_iteration_callback(pipeline.__class__, parameters, self)
-                desc = f"{pipeline.name}"
-                if len(desc) > self._MAX_NAME_LEN:
-                    desc = desc[:self._MAX_NAME_LEN - 3] + "..."
-                desc = desc.ljust(self._MAX_NAME_LEN)
+            current_batch_size = len(current_batch_pipelines)
+            current_batch_pipeline_scores = self._evaluate_pipelines(current_batch_pipelines, search_iteration_plot=search_iteration_plot)
 
-                if self.max_batches:
-                    update_pipeline(logger, desc, len(self._results['pipeline_results']) + 1, self.max_iterations, self._start, self._automl_algorithm.batch_number)
-                else:
-                    update_pipeline(logger, desc, len(self._results['pipeline_results']) + 1, self.max_iterations, self._start)
-
-                evaluation_results = self._evaluate(pipeline, X, y)
-                score = evaluation_results['cv_score_mean']
-                score_to_minimize = -score if self.objective.greater_is_better else score
-                current_batch_pipeline_scores.append(score_to_minimize)
-                self._automl_algorithm.add_result(score_to_minimize, pipeline)
-
-                if search_iteration_plot:
-                    search_iteration_plot.update()
-
-            except KeyboardInterrupt:
-                current_batch_pipelines = self._handle_keyboard_interrupt(pipeline, current_batch_pipelines)
-                if not current_batch_pipelines:
-                    return
+            # Different size indicates early stopping
+            if len(current_batch_pipeline_scores) != current_batch_size:
+                break
 
         elapsed_time = time_elapsed(self._start)
         desc = f"\nSearch finished after {elapsed_time}"
@@ -551,9 +527,42 @@ class AutoMLSearch:
 
         best_pipeline = self.rankings.iloc[0]
         best_pipeline_name = best_pipeline["pipeline_name"]
+        self._best_pipeline = self.get_pipeline(best_pipeline['id'])
+        if self._train_best_pipeline:
+            X_threshold_tuning = None
+            y_threshold_tuning = None
+            X_train, y_train = self.X_train, self.y_train
+            if self.optimize_thresholds and self.objective.is_defined_for_problem_type(ProblemTypes.BINARY) and self.objective.can_optimize_threshold:
+                X_train, X_threshold_tuning, y_train, y_threshold_tuning = split_data(X_train, y_train, self.problem_type,
+                                                                                      test_size=0.2,
+                                                                                      random_state=self.random_seed)
+            self._best_pipeline.fit(X_train, y_train)
+            self._best_pipeline = self._tune_binary_threshold(self._best_pipeline, X_threshold_tuning, y_threshold_tuning)
         logger.info(f"Best pipeline: {best_pipeline_name}")
         logger.info(f"Best pipeline {self.objective.name}: {best_pipeline['score']:3f}")
 
+    def _tune_binary_threshold(self, pipeline, X_threshold_tuning, y_threshold_tuning):
+        """Tunes the threshold of a binary pipeline to the X and y thresholding data
+
+        Arguments:
+            pipeline (Pipeline): Pipeline instance to threshold
+            X_threshold_tuning (ww DataTable): X data to tune pipeline to
+            y_threshold_tuning (ww DataColumn): Target data to tune pipeline to
+
+        Returns:
+            Trained pipeline instance
+        """
+        if self.objective.is_defined_for_problem_type(ProblemTypes.BINARY):
+            pipeline.threshold = 0.5
+            if X_threshold_tuning:
+                y_predict_proba = pipeline.predict_proba(X_threshold_tuning)
+                if isinstance(y_predict_proba, pd.DataFrame):
+                    y_predict_proba = y_predict_proba.iloc[:, 1]
+                else:
+                    y_predict_proba = y_predict_proba[:, 1]
+                pipeline.threshold = self.objective.optimize_threshold(y_predict_proba, y_threshold_tuning, X=X_threshold_tuning)
+        return pipeline
+
     def _check_stopping_condition(self, start):
         should_continue = True
         num_pipelines = len(self._results['pipeline_results'])
@@ -595,15 +604,11 @@ class AutoMLSearch:
             if pipeline.problem_type != self.problem_type:
                 raise ValueError("Given pipeline {} is not compatible with problem_type {}.".format(pipeline.name, self.problem_type.value))
 
-    def _add_baseline_pipelines(self, X, y):
+    def _add_baseline_pipelines(self):
         """Fits a baseline pipeline to the data.
 
         This is the first pipeline fit during search.
 
-        Arguments:
-            X (pd.DataFrame): the input training data of shape [n_samples, n_features]
-            y (pd.Series): the target training data of length [n_samples]
-
         Returns:
             bool - If the user ends the search early, will return True and searching will immediately finish. Else,
                 will return False and more pipelines will be searched.
@@ -613,37 +618,16 @@ class AutoMLSearch:
             baseline = ModeBaselineBinaryPipeline(parameters={})
         elif self.problem_type == ProblemTypes.MULTICLASS:
             baseline = ModeBaselineMulticlassPipeline(parameters={})
-        else:
+        elif self.problem_type == ProblemTypes.REGRESSION:
             baseline = MeanBaselineRegressionPipeline(parameters={})
-
+        else:
+            gap = self.problem_configuration['gap']
+            max_delay = self.problem_configuration['max_delay']
+            baseline = TimeSeriesBaselineRegressionPipeline(parameters={"pipeline": {"gap": gap, "max_delay": max_delay}})
         pipelines = [baseline]
-        # Using a while loop so that we can retry the pipeline after the user hits ctr-c
-        # but decides to not stop the search.
-        while pipelines:
-            try:
-                if self.start_iteration_callback:
-                    self.start_iteration_callback(baseline.__class__, baseline.parameters, self)
-                baseline = pipelines.pop()
-                desc = f"{baseline.name}"
-                if len(desc) > self._MAX_NAME_LEN:
-                    desc = desc[:self._MAX_NAME_LEN - 3] + "..."
-                desc = desc.ljust(self._MAX_NAME_LEN)
-
-                update_pipeline(logger, desc, len(self._results['pipeline_results']) + 1, self.max_iterations,
-                                self._start, 1)
-
-                baseline_results = self._compute_cv_scores(baseline, X, y)
-                self._baseline_cv_scores = self._get_mean_cv_scores_for_all_objectives(baseline_results["cv_data"])
-                self._add_result(trained_pipeline=baseline,
-                                 parameters=baseline.parameters,
-                                 training_time=baseline_results['training_time'],
-                                 cv_data=baseline_results['cv_data'],
-                                 cv_scores=baseline_results['cv_scores'])
-            except KeyboardInterrupt:
-                pipelines = self._handle_keyboard_interrupt(baseline, pipelines)
-                if not pipelines:
-                    return True
-
+        scores = self._evaluate_pipelines(pipelines, baseline=True)
+        if scores == []:
+            return True
         return False
 
     @staticmethod
@@ -657,29 +641,26 @@ class AutoMLSearch:
                     scores[field] += value
         return {objective_name: float(score) / n_folds for objective_name, score in scores.items()}
 
-    def _compute_cv_scores(self, pipeline, X, y):
+    def _compute_cv_scores(self, pipeline):
         start = time.time()
         cv_data = []
         logger.info("\tStarting cross validation")
-        X = _convert_to_woodwork_structure(X)
-        y = _convert_to_woodwork_structure(y)
-
-        X_pd = _convert_woodwork_types_wrapper(X.to_dataframe())
-        y_pd = _convert_woodwork_types_wrapper(y.to_series())
-        for i, (train, test) in enumerate(self.data_split.split(X_pd, y_pd)):
+        X_pd = _convert_woodwork_types_wrapper(self.X_train.to_dataframe())
+        y_pd = _convert_woodwork_types_wrapper(self.y_train.to_series())
+        for i, (train, valid) in enumerate(self.data_splitter.split(X_pd, y_pd)):
 
             if pipeline.model_family == ModelFamily.ENSEMBLE and i > 0:
                 # Stacked ensembles do CV internally, so we do not run CV here for performance reasons.
                 logger.debug(f"Skipping fold {i} because CV for stacked ensembles is not supported.")
                 break
             logger.debug(f"\t\tTraining and scoring on fold {i}")
-            X_train, X_test = X.iloc[train], X.iloc[test]
-            y_train, y_test = y.iloc[train], y.iloc[test]
+            X_train, X_valid = self.X_train.iloc[train], self.X_train.iloc[valid]
+            y_train, y_valid = self.y_train.iloc[train], self.y_train.iloc[valid]
             if self.problem_type in [ProblemTypes.BINARY, ProblemTypes.MULTICLASS]:
-                diff_train = set(np.setdiff1d(y.to_series(), y_train.to_series()))
-                diff_test = set(np.setdiff1d(y.to_series(), y_test.to_series()))
+                diff_train = set(np.setdiff1d(self.y_train.to_series(), y_train.to_series()))
+                diff_valid = set(np.setdiff1d(self.y_train.to_series(), y_valid.to_series()))
                 diff_string = f"Missing target values in the training set after data split: {diff_train}. " if diff_train else ""
-                diff_string += f"Missing target values in the test set after data split: {diff_test}." if diff_test else ""
+                diff_string += f"Missing target values in the validation set after data split: {diff_valid}." if diff_valid else ""
                 if diff_string:
                     raise Exception(diff_string)
             objectives_to_score = [self.objective] + self.additional_objectives
@@ -688,28 +669,21 @@ class AutoMLSearch:
                 X_threshold_tuning = None
                 y_threshold_tuning = None
                 if self.optimize_thresholds and self.objective.is_defined_for_problem_type(ProblemTypes.BINARY) and self.objective.can_optimize_threshold:
-                    X_train, X_threshold_tuning, y_train, y_threshold_tuning = train_test_split(X_train, y_train, test_size=0.2, random_state=self.random_state)
+                    X_train, X_threshold_tuning, y_train, y_threshold_tuning = split_data(X_train, y_train, self.problem_type,
+                                                                                          test_size=0.2,
+                                                                                          random_state=self.random_seed)
                 cv_pipeline = pipeline.clone(pipeline.random_state)
                 logger.debug(f"\t\t\tFold {i}: starting training")
                 cv_pipeline.fit(X_train, y_train)
                 logger.debug(f"\t\t\tFold {i}: finished training")
-                if self.objective.is_defined_for_problem_type(ProblemTypes.BINARY):
-                    cv_pipeline.threshold = 0.5
-                    if self.optimize_thresholds and self.objective.can_optimize_threshold:
-                        logger.debug(f"\t\t\tFold {i}: Optimizing threshold for {self.objective.name}")
-                        y_predict_proba = cv_pipeline.predict_proba(X_threshold_tuning)
-                        if isinstance(y_predict_proba, pd.DataFrame):
-                            y_predict_proba = y_predict_proba.iloc[:, 1]
-                        else:
-                            y_predict_proba = y_predict_proba[:, 1]
-                        cv_pipeline.threshold = self.objective.optimize_threshold(y_predict_proba, y_threshold_tuning, X=X_threshold_tuning)
-                        logger.debug(f"\t\t\tFold {i}: Optimal threshold found ({cv_pipeline.threshold:.3f})")
+                cv_pipeline = self._tune_binary_threshold(cv_pipeline, X_threshold_tuning, y_threshold_tuning)
+                if X_threshold_tuning:
+                    logger.debug(f"\t\t\tFold {i}: Optimal threshold found ({cv_pipeline.threshold:.3f})")
                 logger.debug(f"\t\t\tFold {i}: Scoring trained pipeline")
-                scores = cv_pipeline.score(X_test, y_test, objectives=objectives_to_score)
+                scores = cv_pipeline.score(X_valid, y_valid, objectives=objectives_to_score)
                 logger.debug(f"\t\t\tFold {i}: {self.objective.name} score: {scores[self.objective.name]:.3f}")
                 score = scores[self.objective.name]
             except Exception as e:
-
                 if self.error_callback is not None:
                     self.error_callback(exception=e, traceback=traceback.format_tb(sys.exc_info()[2]), automl=self,
                                         fold_num=i, pipeline=pipeline)
@@ -726,7 +700,7 @@ class AutoMLSearch:
             ordered_scores.update({self.objective.name: score})
             ordered_scores.update(scores)
             ordered_scores.update({"# Training": y_train.shape[0]})
-            ordered_scores.update({"# Testing": y_test.shape[0]})
+            ordered_scores.update({"# Validation": y_valid.shape[0]})
 
             evaluation_entry = {"all_objective_scores": ordered_scores, "score": score, 'binary_classification_threshold': None}
             if isinstance(cv_pipeline, BinaryClassificationPipeline) and cv_pipeline.threshold is not None:
@@ -782,18 +756,64 @@ class AutoMLSearch:
         if self.add_result_callback:
             self.add_result_callback(self._results['pipeline_results'][pipeline_id], trained_pipeline, self)
 
-    def _evaluate(self, pipeline, X, y):
-        parameters = pipeline.parameters
-        evaluation_results = self._compute_cv_scores(pipeline, X, y)
-        logger.debug('Adding results for pipeline {}\nparameters {}\nevaluation_results {}'.format(pipeline.name, parameters, evaluation_results))
+    def _evaluate_pipelines(self, current_pipeline_batch, baseline=False, search_iteration_plot=None):
+        current_batch_pipeline_scores = []
+        add_single_pipeline = False
+        if isinstance(current_pipeline_batch, PipelineBase):
+            current_pipeline_batch = [current_pipeline_batch]
+            add_single_pipeline = True
 
-        self._add_result(trained_pipeline=pipeline,
-                         parameters=parameters,
-                         training_time=evaluation_results['training_time'],
-                         cv_data=evaluation_results['cv_data'],
-                         cv_scores=evaluation_results['cv_scores'])
-        logger.debug('Adding results complete')
-        return evaluation_results
+        while len(current_pipeline_batch) > 0 and (add_single_pipeline or baseline or self._check_stopping_condition(self._start)):
+            pipeline = current_pipeline_batch.pop()
+            try:
+                parameters = pipeline.parameters
+                logger.debug('Evaluating pipeline {}'.format(pipeline.name))
+                logger.debug('Pipeline parameters: {}'.format(parameters))
+
+                if self.start_iteration_callback:
+                    self.start_iteration_callback(pipeline.__class__, parameters, self)
+                desc = f"{pipeline.name}"
+                if len(desc) > self._MAX_NAME_LEN:
+                    desc = desc[:self._MAX_NAME_LEN - 3] + "..."
+                desc = desc.ljust(self._MAX_NAME_LEN)
+
+                if not add_single_pipeline:
+                    update_pipeline(logger, desc, len(self._results['pipeline_results']) + 1, self.max_iterations,
+                                    self._start, 1 if baseline else self._automl_algorithm.batch_number, self.show_batch_output)
+
+                evaluation_results = self._compute_cv_scores(pipeline)
+                parameters = pipeline.parameters
+
+                if baseline:
+                    self._baseline_cv_scores = self._get_mean_cv_scores_for_all_objectives(evaluation_results["cv_data"])
+
+                logger.debug('Adding results for pipeline {}\nparameters {}\nevaluation_results {}'.format(pipeline.name, parameters, evaluation_results))
+                self._add_result(trained_pipeline=pipeline,
+                                 parameters=parameters,
+                                 training_time=evaluation_results['training_time'],
+                                 cv_data=evaluation_results['cv_data'],
+                                 cv_scores=evaluation_results['cv_scores'])
+                logger.debug('Adding results complete')
+
+                score = evaluation_results['cv_score_mean']
+                score_to_minimize = -score if self.objective.greater_is_better else score
+                current_batch_pipeline_scores.append(score_to_minimize)
+
+                if not baseline and not add_single_pipeline:
+                    self._automl_algorithm.add_result(score_to_minimize, pipeline)
+
+                if search_iteration_plot:
+                    search_iteration_plot.update()
+
+                if add_single_pipeline:
+                    add_single_pipeline = False
+
+            except KeyboardInterrupt:
+                current_pipeline_batch = self._handle_keyboard_interrupt(pipeline, current_pipeline_batch)
+                if current_pipeline_batch == []:
+                    return current_batch_pipeline_scores
+
+        return current_batch_pipeline_scores
 
     def get_pipeline(self, pipeline_id, random_state=0):
         """Given the ID of a pipeline training result, returns an untrained instance of the specified pipeline
@@ -847,7 +867,7 @@ class AutoMLSearch:
         all_objective_scores = pd.DataFrame(all_objective_scores)
 
         for c in all_objective_scores:
-            if c in ["# Training", "# Testing"]:
+            if c in ["# Training", "# Validation"]:
                 all_objective_scores[c] = all_objective_scores[c].astype("object")
                 continue
 
@@ -865,29 +885,17 @@ class AutoMLSearch:
         if return_dict:
             return pipeline_results
 
-    def add_to_rankings(self, pipeline, X, y):
+    def add_to_rankings(self, pipeline):
         """Fits and evaluates a given pipeline then adds the results to the automl rankings with the requirement that automl search has been run.
-        Please use the same data as previous runs of automl search. If pipeline already exists in rankings this method will return `None`.
 
         Arguments:
             pipeline (PipelineBase): pipeline to train and evaluate.
-
-            X (pd.DataFrame): the input training data of shape [n_samples, n_features].
-
-            y (pd.Series): the target training data of length [n_samples].
         """
-        if not isinstance(X, pd.DataFrame):
-            X = pd.DataFrame(X)
-        if not isinstance(y, pd.Series):
-            y = pd.Series(y)
-
-        self._set_data_split(X)
-
         pipeline_rows = self.full_rankings[self.full_rankings['pipeline_name'] == pipeline.name]
         for parameter in pipeline_rows['parameters']:
             if pipeline.parameters == parameter:
                 return
-        self._evaluate(pipeline, X, y)
+        self._evaluate_pipelines(pipeline)
 
     @property
     def results(self):
@@ -929,16 +937,15 @@ class AutoMLSearch:
 
     @property
     def best_pipeline(self):
-        """Returns an untrained instance of the best pipeline and parameters found during automl search.
+        """Returns a trained instance of the best pipeline and parameters found during automl search. If `train_best_pipeline` is set to False, returns an untrained pipeline instance.
 
         Returns:
-            PipelineBase: untrained pipeline instance associated with the best automl search result.
+            PipelineBase: A trained instance of the best pipeline and parameters found during automl search. If `train_best_pipeline` is set to False, returns an untrained pipeline instance.
         """
-        if not self.has_searched:
+        if not (self.has_searched and self._best_pipeline):
             raise PipelineNotFoundError("automl search must be run before selecting `best_pipeline`.")
 
-        best = self.rankings.iloc[0]
-        return self.get_pipeline(best["id"])
+        return self._best_pipeline
 
     def save(self, file_path, pickle_protocol=cloudpickle.DEFAULT_PROTOCOL):
         """Saves AutoML object at file path
