@@ -1,4 +1,3 @@
-import pandas as pd
 
 from evalml.data_checks import (
     DataCheck,
@@ -6,6 +5,10 @@ from evalml.data_checks import (
     DataCheckMessageCode,
     DataCheckWarning
 )
+from evalml.utils.gen_utils import (
+    _convert_to_woodwork_structure,
+    _convert_woodwork_types_wrapper
+)
 
 
 class ClassImbalanceDataCheck(DataCheck):
@@ -33,15 +36,16 @@ class ClassImbalanceDataCheck(DataCheck):
             Ignores NaN values in target labels if they appear.
 
         Arguments:
-            X (pd.DataFrame, pd.Series, np.ndarray, list): Features. Ignored.
-            y: Target labels to check for imbalanced data.
+            X (ww.DataTable, pd.DataFrame, np.ndarray): Features. Ignored.
+            y (ww.DataColumn, pd.Series, np.ndarray): Target labels to check for imbalanced data.
 
         Returns:
             dict: Dictionary with DataCheckWarnings if imbalance in classes is less than the threshold,
                   and DataCheckErrors if the number of values for each target is below 2 * num_cv_folds.
 
         Example:
-            >>> X = pd.DataFrame({})
+            >>> import pandas as pd
+            >>> X = pd.DataFrame()
             >>> y = pd.Series([0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1])
             >>> target_check = ClassImbalanceDataCheck(threshold=0.10)
         >>> assert target_check.validate(X, y) == {"errors": [{"message": "The number of instances of these targets is less than 2 * the number of cross folds = 6 instances: [0]",\
@@ -59,8 +63,10 @@ class ClassImbalanceDataCheck(DataCheck):
             "warnings": [],
             "errors": []
         }
-        if not isinstance(y, pd.Series):
-            y = pd.Series(y)
+
+        y = _convert_to_woodwork_structure(y)
+        y = _convert_woodwork_types_wrapper(y.to_series())
+
         fold_counts = y.value_counts(normalize=False)
         # search for targets that occur less than twice the number of cv folds first
         below_threshold_folds = fold_counts.where(fold_counts < self.cv_folds).dropna()
