@@ -1,10 +1,13 @@
-import pandas as pd
 
 from evalml.data_checks import (
     DataCheck,
     DataCheckMessageCode,
     DataCheckWarning
 )
+from evalml.utils.gen_utils import (
+    _convert_to_woodwork_structure,
+    _convert_woodwork_types_wrapper
+)
 
 
 class IDColumnsDataCheck(DataCheck):
@@ -28,13 +31,13 @@ class IDColumnsDataCheck(DataCheck):
             - column contains all unique values (and is not float / boolean)
 
         Arguments:
-            X (pd.DataFrame): The input features to check
-            threshold (float): The probability threshold to be considered an ID column. Defaults to 1.0
+            X (ww.DataTable, pd.DataFrame, np.ndarray): The input features to check
 
         Returns:
             dict: A dictionary of features with column name or index and their probability of being ID columns
 
         Example:
+            >>> import pandas as pd
             >>> df = pd.DataFrame({
             ...     'df_id': [0, 1, 2, 3, 4],
             ...     'x': [10, 42, 31, 51, 61],
@@ -52,8 +55,10 @@ class IDColumnsDataCheck(DataCheck):
             "warnings": [],
             "errors": []
         }
-        if not isinstance(X, pd.DataFrame):
-            X = pd.DataFrame(X)
+
+        X = _convert_to_woodwork_structure(X)
+        X = _convert_woodwork_types_wrapper(X.to_dataframe())
+
         col_names = [col for col in X.columns.tolist()]
         cols_named_id = [col for col in col_names if (str(col).lower() == "id")]  # columns whose name is "id"
         id_cols = {col: 0.95 for col in cols_named_id}
