@@ -1,8 +1,12 @@
 import copy
+import os
 import warnings
+from collections import OrderedDict
 
 import numpy as np
 import pandas as pd
+import woodwork as ww
+from sklearn.exceptions import NotFittedError
 from sklearn.inspection import partial_dependence as sk_partial_dependence
 from sklearn.inspection import \
     permutation_importance as sk_permutation_importance
@@ -12,6 +16,7 @@ from sklearn.metrics import \
     precision_recall_curve as sklearn_precision_recall_curve
 from sklearn.metrics import roc_curve as sklearn_roc_curve
 from sklearn.preprocessing import LabelBinarizer
+from sklearn.tree import export_graphviz
 from sklearn.utils.multiclass import unique_labels
 
 import evalml
@@ -19,25 +24,29 @@ from evalml.exceptions import NullsInColumnWarning
 from evalml.model_family import ModelFamily
 from evalml.objectives.utils import get_objective
 from evalml.problem_types import ProblemTypes
-from evalml.utils import import_or_raise, jupyter_check
+from evalml.utils import (
+    _convert_to_woodwork_structure,
+    _convert_woodwork_types_wrapper,
+    import_or_raise,
+    jupyter_check
+)
 
 
 def confusion_matrix(y_true, y_predicted, normalize_method='true'):
     """Confusion matrix for binary and multiclass classification.
 
     Arguments:
-        y_true (pd.Series or np.ndarray): True binary labels.
-        y_pred (pd.Series or np.ndarray): Predictions from a binary classifier.
-        normalize_method ({'true', 'pred', 'all'}): Normalization method. Supported options are: 'true' to normalize by row, 'pred' to normalize by column, or 'all' to normalize by all values. Defaults to 'true'.
+        y_true (ww.DataColumn, pd.Series or np.ndarray): True binary labels.
+        y_pred (ww.DataColumn, pd.Series or np.ndarray): Predictions from a binary classifier.
+        normalize_method ({'true', 'pred', 'all', None}): Normalization method to use, if not None. Supported options are: 'true' to normalize by row, 'pred' to normalize by column, or 'all' to normalize by all values. Defaults to 'true'.
 
     Returns:
         pd.DataFrame: Confusion matrix. The column header represents the predicted labels while row header represents the actual labels.
     """
-    if isinstance(y_true, pd.Series):
-        y_true = y_true.to_numpy()
-    if isinstance(y_predicted, pd.Series):
-        y_predicted = y_predicted.to_numpy()
-
+    y_true = _convert_to_woodwork_structure(y_true)
+    y_predicted = _convert_to_woodwork_structure(y_predicted)
+    y_true = _convert_woodwork_types_wrapper(y_true.to_series()).to_numpy()
+    y_predicted = _convert_woodwork_types_wrapper(y_predicted.to_series()).to_numpy()
     labels = unique_labels(y_true, y_predicted)
     conf_mat = sklearn_confusion_matrix(y_true, y_predicted)
     conf_mat = pd.DataFrame(conf_mat, index=labels, columns=labels)
@@ -50,12 +59,17 @@ def normalize_confusion_matrix(conf_mat, normalize_method='true'):
     """Normalizes a confusion matrix.
 
     Arguments:
-        conf_mat (pd.DataFrame or np.ndarray): Confusion matrix to normalize.
+        conf_mat (ww.DataTable, pd.DataFrame or np.ndarray): Confusion matrix to normalize.
         normalize_method ({'true', 'pred', 'all'}): Normalization method. Supported options are: 'true' to normalize by row, 'pred' to normalize by column, or 'all' to normalize by all values. Defaults to 'true'.
 
     Returns:
         pd.DataFrame: normalized version of the input confusion matrix. The column header represents the predicted labels while row header represents the actual labels.
     """
+    conf_mat = _convert_to_woodwork_structure(conf_mat)
+    conf_mat = _convert_woodwork_types_wrapper(conf_mat.to_dataframe())
+    col_names = conf_mat.columns
+
+    conf_mat = conf_mat.to_numpy()
     with warnings.catch_warnings(record=True) as w:
         if normalize_method == 'true':
             conf_mat = conf_mat.astype('float') / conf_mat.sum(axis=1)[:, np.newaxis]
@@ -64,19 +78,63 @@ def normalize_confusion_matrix(conf_mat, normalize_method='true'):
         elif normalize_method == 'all':
             conf_mat = conf_mat.astype('float') / conf_mat.sum().sum()
         else:
-            raise ValueError('Invalid value provided for "normalize_method": %s'.format(normalize_method))
+            raise ValueError('Invalid value provided for "normalize_method": {}'.format(normalize_method))
         if w and "invalid value encountered in" in str(w[0].message):
             raise ValueError("Sum of given axis is 0 and normalization is not possible. Please select another option.")
+    conf_mat = pd.DataFrame(conf_mat, index=col_names, columns=col_names)
     return conf_mat
 
 
+def graph_confusion_matrix(y_true, y_pred, normalize_method='true', title_addition=None):
+    """Generate and display a confusion matrix plot.
+
+    If `normalize_method` is set, hover text will show raw count, otherwise hover text will show count normalized with method 'true'.
+
+    Arguments:
+        y_true (ww.DataColumn, pd.Series or np.ndarray): True binary labels.
+        y_pred (ww.DataColumn, pd.Series or np.ndarray): Predictions from a binary classifier.
+        normalize_method ({'true', 'pred', 'all', None}): Normalization method to use, if not None. Supported options are: 'true' to normalize by row, 'pred' to normalize by column, or 'all' to normalize by all values. Defaults to 'true'.
+        title_addition (str or None): if not None, append to plot title. Defaults to None.
+
+    Returns:
+        plotly.Figure representing the confusion matrix plot generated
+    """
+    _go = import_or_raise("plotly.graph_objects", error_msg="Cannot find dependency plotly.graph_objects")
+    if jupyter_check():
+        import_or_raise("ipywidgets", warning=True)
+
+    conf_mat = confusion_matrix(y_true, y_pred, normalize_method=None)
+    conf_mat_normalized = confusion_matrix(y_true, y_pred, normalize_method=normalize_method or 'true')
+    labels = conf_mat.columns
+
+    title = 'Confusion matrix{}{}'.format(
+        '' if title_addition is None else (' ' + title_addition),
+        '' if normalize_method is None else (', normalized using method "' + normalize_method + '"'))
+    z_data, custom_data = (conf_mat, conf_mat_normalized) if normalize_method is None else (conf_mat_normalized, conf_mat)
+    primary_heading, secondary_heading = ('Raw', 'Normalized') if normalize_method is None else ('Normalized', 'Raw')
+    hover_text = '<br><b>' + primary_heading + ' Count</b>: %{z}<br><b>' + secondary_heading + ' Count</b>: %{customdata} <br>'
+    # the "<extra> tags at the end are necessary to remove unwanted trace info
+    hover_template = '<b>True</b>: %{y}<br><b>Predicted</b>: %{x}' + hover_text + '<extra></extra>'
+    layout = _go.Layout(title={'text': title},
+                        xaxis={'title': 'Predicted Label', 'type': 'category', 'tickvals': labels},
+                        yaxis={'title': 'True Label', 'type': 'category', 'tickvals': labels})
+    fig = _go.Figure(data=_go.Heatmap(x=labels, y=labels, z=z_data,
+                                      customdata=custom_data,
+                                      hovertemplate=hover_template,
+                                      colorscale='Blues'),
+                     layout=layout)
+    # plotly Heatmap y axis defaults to the reverse of what we want: https://community.plotly.com/t/heatmap-y-axis-is-reversed-by-default-going-against-standard-convention-for-matrices/32180
+    fig.update_yaxes(autorange="reversed")
+    return fig
+
+
 def precision_recall_curve(y_true, y_pred_proba):
     """
     Given labels and binary classifier predicted probabilities, compute and return the data representing a precision-recall curve.
 
     Arguments:
-        y_true (pd.Series or np.ndarray): True binary labels.
-        y_pred_proba (pd.Series or np.ndarray): Predictions from a binary classifier, before thresholding has been applied. Note this should be the predicted probability for the "true" label.
+        y_true (ww.DataColumn, pd.Series or np.ndarray): True binary labels.
+        y_pred_proba (ww.DataColumn, pd.Series or np.ndarray): Predictions from a binary classifier, before thresholding has been applied. Note this should be the predicted probability for the "true" label.
 
     Returns:
         list: Dictionary containing metrics used to generate a precision-recall plot, with the following keys:
@@ -86,6 +144,11 @@ def precision_recall_curve(y_true, y_pred_proba):
                   * `thresholds`: Threshold values used to produce the precision and recall.
                   * `auc_score`: The area under the ROC curve.
     """
+    y_true = _convert_to_woodwork_structure(y_true)
+    y_pred_proba = _convert_to_woodwork_structure(y_pred_proba)
+    y_true = _convert_woodwork_types_wrapper(y_true.to_series())
+    y_pred_proba = _convert_woodwork_types_wrapper(y_pred_proba.to_series())
+
     precision, recall, thresholds = sklearn_precision_recall_curve(y_true, y_pred_proba)
     auc_score = sklearn_auc(recall, precision)
     return {'precision': precision,
@@ -98,8 +161,8 @@ def graph_precision_recall_curve(y_true, y_pred_proba, title_addition=None):
     """Generate and display a precision-recall plot.
 
     Arguments:
-        y_true (pd.Series or np.ndarray): True binary labels.
-        y_pred_proba (pd.Series or np.ndarray): Predictions from a binary classifier, before thresholding has been applied. Note this should be the predicted probability for the "true" label.
+        y_true (ww.DataColumn, pd.Series or np.ndarray): True binary labels.
+        y_pred_proba (ww.DataColumn, pd.Series or np.ndarray): Predictions from a binary classifier, before thresholding has been applied. Note this should be the predicted probability for the "true" label.
         title_addition (str or None): If not None, append to plot title. Default None.
 
     Returns:
@@ -108,12 +171,6 @@ def graph_precision_recall_curve(y_true, y_pred_proba, title_addition=None):
     _go = import_or_raise("plotly.graph_objects", error_msg="Cannot find dependency plotly.graph_objects")
     if jupyter_check():
         import_or_raise("ipywidgets", warning=True)
-
-    if isinstance(y_true, pd.Series):
-        y_true = y_true.to_numpy()
-    if isinstance(y_pred_proba, (pd.Series, pd.DataFrame)):
-        y_pred_proba = y_pred_proba.to_numpy()
-
     precision_recall_curve_data = precision_recall_curve(y_true, y_pred_proba)
     title = 'Precision-Recall{}'.format('' if title_addition is None else (' ' + title_addition))
     layout = _go.Layout(title={'text': title},
@@ -131,8 +188,8 @@ def roc_curve(y_true, y_pred_proba):
     Given labels and classifier predicted probabilities, compute and return the data representing a Receiver Operating Characteristic (ROC) curve. Works with binary or multiclass problems.
 
     Arguments:
-        y_true (pd.Series or np.ndarray): True labels.
-        y_pred_proba (pd.Series or np.ndarray): Predictions from a classifier, before thresholding has been applied.
+        y_true (ww.DataColumn, pd.Series or np.ndarray): True labels.
+        y_pred_proba (ww.DataColumn, pd.Series or np.ndarray): Predictions from a classifier, before thresholding has been applied.
 
     Returns:
         list(dict): A list of dictionaries (with one for each class) is returned. Binary classification problems return a list with one dictionary.
@@ -142,16 +199,18 @@ def roc_curve(y_true, y_pred_proba):
                   * `threshold`: Threshold values used to produce each pair of true/false positive rates.
                   * `auc_score`: The area under the ROC curve.
     """
-    if isinstance(y_true, pd.Series):
-        y_true = y_true.to_numpy()
-    if isinstance(y_pred_proba, (pd.Series, pd.DataFrame)):
-        y_pred_proba = y_pred_proba.to_numpy()
+    y_true = _convert_to_woodwork_structure(y_true)
+    y_pred_proba = _convert_to_woodwork_structure(y_pred_proba)
+    if isinstance(y_pred_proba, ww.DataTable):
+        y_pred_proba = _convert_woodwork_types_wrapper(y_pred_proba.to_dataframe()).to_numpy()
+    else:
+        y_pred_proba = _convert_woodwork_types_wrapper(y_pred_proba.to_series()).to_numpy()
+    y_true = _convert_woodwork_types_wrapper(y_true.to_series()).to_numpy()
 
-    if y_pred_proba.ndim == 1:
+    if len(y_pred_proba.shape) == 1:
         y_pred_proba = y_pred_proba.reshape(-1, 1)
     if y_pred_proba.shape[1] == 2:
         y_pred_proba = y_pred_proba[:, 1].reshape(-1, 1)
-
     nan_indices = np.logical_or(pd.isna(y_true), np.isnan(y_pred_proba).any(axis=1))
     y_true = y_true[~nan_indices]
     y_pred_proba = y_pred_proba[~nan_indices]
@@ -177,8 +236,8 @@ def graph_roc_curve(y_true, y_pred_proba, custom_class_names=None, title_additio
     """Generate and display a Receiver Operating Characteristic (ROC) plot for binary and multiclass classification problems.
 
     Arguments:
-        y_true (pd.Series or np.ndarray): True labels.
-        y_pred_proba (pd.Series or np.ndarray): Predictions from a classifier, before thresholding has been applied. Note this should a one dimensional array with the predicted probability for the "true" label in the binary case.
+        y_true (ww.DataColumn, pd.Series or np.ndarray): True labels.
+        y_pred_proba (ww.DataColumn, pd.Series or np.ndarray): Predictions from a classifier, before thresholding has been applied. Note this should a one dimensional array with the predicted probability for the "true" label in the binary case.
         custom_class_labels (list or None): If not None, custom labels for classes. Default None.
         title_addition (str or None): if not None, append to plot title. Default None.
 
@@ -216,61 +275,13 @@ def graph_roc_curve(y_true, y_pred_proba, custom_class_names=None, title_additio
     return _go.Figure(layout=layout, data=graph_data)
 
 
-def graph_confusion_matrix(y_true, y_pred, normalize_method='true', title_addition=None):
-    """Generate and display a confusion matrix plot.
-
-    If `normalize_method` is set, hover text will show raw count, otherwise hover text will show count normalized with method 'true'.
-
-    Arguments:
-        y_true (pd.Series or np.ndarray): True binary labels.
-        y_pred (pd.Series or np.ndarray): Predictions from a binary classifier.
-        normalize_method ({'true', 'pred', 'all'}): Normalization method. Supported options are: 'true' to normalize by row, 'pred' to normalize by column, or 'all' to normalize by all values. Defaults to 'true'.
-        title_addition (str or None): if not None, append to plot title. Default None.
-
-    Returns:
-        plotly.Figure representing the confusion matrix plot generated
-    """
-    _go = import_or_raise("plotly.graph_objects", error_msg="Cannot find dependency plotly.graph_objects")
-    if jupyter_check():
-        import_or_raise("ipywidgets", warning=True)
-
-    if isinstance(y_true, pd.Series):
-        y_true = y_true.to_numpy()
-    if isinstance(y_pred, pd.Series):
-        y_pred = y_pred.to_numpy()
-
-    conf_mat = confusion_matrix(y_true, y_pred, normalize_method=None)
-    conf_mat_normalized = confusion_matrix(y_true, y_pred, normalize_method=normalize_method or 'true')
-    labels = conf_mat.columns
-
-    title = 'Confusion matrix{}{}'.format(
-        '' if title_addition is None else (' ' + title_addition),
-        '' if normalize_method is None else (', normalized using method "' + normalize_method + '"'))
-    z_data, custom_data = (conf_mat, conf_mat_normalized) if normalize_method is None else (conf_mat_normalized, conf_mat)
-    primary_heading, secondary_heading = ('Raw', 'Normalized') if normalize_method is None else ('Normalized', 'Raw')
-    hover_text = '<br><b>' + primary_heading + ' Count</b>: %{z}<br><b>' + secondary_heading + ' Count</b>: %{customdata} <br>'
-    # the "<extra> tags at the end are necessary to remove unwanted trace info
-    hover_template = '<b>True</b>: %{y}<br><b>Predicted</b>: %{x}' + hover_text + '<extra></extra>'
-    layout = _go.Layout(title={'text': title},
-                        xaxis={'title': 'Predicted Label', 'type': 'category', 'tickvals': labels},
-                        yaxis={'title': 'True Label', 'type': 'category', 'tickvals': labels})
-    fig = _go.Figure(data=_go.Heatmap(x=labels, y=labels, z=z_data,
-                                      customdata=custom_data,
-                                      hovertemplate=hover_template,
-                                      colorscale='Blues'),
-                     layout=layout)
-    # plotly Heatmap y axis defaults to the reverse of what we want: https://community.plotly.com/t/heatmap-y-axis-is-reversed-by-default-going-against-standard-convention-for-matrices/32180
-    fig.update_yaxes(autorange="reversed")
-    return fig
-
-
 def calculate_permutation_importance(pipeline, X, y, objective, n_repeats=5, n_jobs=None, random_state=0):
     """Calculates permutation importance for features.
 
     Arguments:
         pipeline (PipelineBase or subclass): Fitted pipeline
-        X (pd.DataFrame): The input data used to score and compute permutation importance
-        y (pd.Series): The target data
+        X (ww.DataTable, pd.DataFrame): The input data used to score and compute permutation importance
+        y (ww.DataColumn, pd.Series): The target data
         objective (str, ObjectiveBase): Objective to score on
         n_repeats (int): Number of times to permute a feature. Defaults to 5.
         n_jobs (int or None): Non-negative integer describing level of parallelism used for pipelines.
@@ -280,6 +291,11 @@ def calculate_permutation_importance(pipeline, X, y, objective, n_repeats=5, n_j
     Returns:
         Mean feature importance scores over 5 shuffles.
     """
+    X = _convert_to_woodwork_structure(X)
+    y = _convert_to_woodwork_structure(y)
+    X = _convert_woodwork_types_wrapper(X.to_dataframe())
+    y = _convert_woodwork_types_wrapper(y.to_series())
+
     objective = get_objective(objective, return_instance=True)
     if not objective.is_defined_for_problem_type(pipeline.problem_type):
         raise ValueError(f"Given objective '{objective.name}' cannot be used with '{pipeline.name}'")
@@ -302,8 +318,8 @@ def graph_permutation_importance(pipeline, X, y, objective, importance_threshold
 
     Arguments:
         pipeline (PipelineBase or subclass): Fitted pipeline
-        X (pd.DataFrame): The input data used to score and compute permutation importance
-        y (pd.Series): The target data
+        X (ww.DataTable, pd.DataFrame): The input data used to score and compute permutation importance
+        y (ww.DataColumn, pd.Series): The target data
         objective (str, ObjectiveBase): Objective to score on
         importance_threshold (float, optional): If provided, graph features with a permutation importance whose absolute value is larger than importance_threshold. Defaults to zero.
 
@@ -353,8 +369,8 @@ def binary_objective_vs_threshold(pipeline, X, y, objective, steps=100):
 
     Arguments:
         pipeline (BinaryClassificationPipeline obj): Fitted binary classification pipeline
-        X (pd.DataFrame): The input data used to compute objective score
-        y (pd.Series): The target labels
+        X (ww.DataTable, pd.DataFrame): The input data used to compute objective score
+        y (ww.DataColumn, pd.Series): The target labels
         objective (ObjectiveBase obj, str): Objective used to score
         steps (int): Number of intervals to divide and calculate objective score at
 
@@ -384,8 +400,8 @@ def graph_binary_objective_vs_threshold(pipeline, X, y, objective, steps=100):
 
     Arguments:
         pipeline (PipelineBase or subclass): Fitted pipeline
-        X (pd.DataFrame): The input data used to score and compute scores
-        y (pd.Series): The target labels
+        X (ww.DataTable, pd.DataFrame): The input data used to score and compute scores
+        y (ww.DataColumn, pd.Series): The target labels
         objective (ObjectiveBase obj, str): Objective used to score, shown on the y-axis of the graph
         steps (int): Number of intervals to divide and calculate objective score at
 
@@ -415,7 +431,7 @@ def partial_dependence(pipeline, X, feature, grid_resolution=100):
 
     Arguments:
         pipeline (PipelineBase or subclass): Fitted pipeline
-        X (pd.DataFrame, np.ndarray): The input data used to generate a grid of values
+        X (ww.DataTable, pd.DataFrame, np.ndarray): The input data used to generate a grid of values
             for feature where partial dependence will be calculated at
         feature (int, string): The target features for which to create the partial dependence plot for.
             If feature is an int, it must be the index of the feature to use.
@@ -423,11 +439,17 @@ def partial_dependence(pipeline, X, feature, grid_resolution=100):
 
     Returns:
         pd.DataFrame: DataFrame with averaged predictions for all points in the grid averaged
-            over all samples of X and the values used to calculate those predictions.
+            over all samples of X and the values used to calculate those predictions. The dataframe will
+            contain two columns: "feature_values" (grid points at which the partial dependence was calculated) and
+            "partial_dependence" (the partial dependence at that feature value). For classification problems, there
+            will be a third column called "class_label" (the class label for which the partial
+            dependence was calculated). For binary classification, the partial dependence is only calculated for the
+            "positive" class.
 
     """
-    if not isinstance(X, pd.DataFrame):
-        X = pd.DataFrame(X)
+    X = _convert_to_woodwork_structure(X)
+    X = _convert_woodwork_types_wrapper(X.to_dataframe())
+
     if not pipeline._is_fitted:
         raise ValueError("Pipeline to calculate partial dependence for must be fitted")
     if pipeline.model_family == ModelFamily.BASELINE:
@@ -445,20 +467,34 @@ def partial_dependence(pipeline, X, feature, grid_resolution=100):
         # Delete scikit-learn attributes that were temporarily set
         del pipeline._estimator_type
         del pipeline.feature_importances_
-    return pd.DataFrame({"feature_values": values[0],
-                         "partial_dependence": avg_pred[0]})
+    classes = None
+    if isinstance(pipeline, evalml.pipelines.BinaryClassificationPipeline):
+        classes = [pipeline.classes_[1]]
+    elif isinstance(pipeline, evalml.pipelines.MulticlassClassificationPipeline):
+        classes = pipeline.classes_
+
+    data = pd.DataFrame({"feature_values": np.tile(values[0], avg_pred.shape[0]),
+                         "partial_dependence": np.concatenate([pred for pred in avg_pred])})
+    if classes is not None:
+        data['class_label'] = np.repeat(classes, len(values[0]))
+
+    return data
 
 
-def graph_partial_dependence(pipeline, X, feature, grid_resolution=100):
+def graph_partial_dependence(pipeline, X, feature, class_label=None, grid_resolution=100):
     """Create an one-way partial dependence plot.
 
     Arguments:
         pipeline (PipelineBase or subclass): Fitted pipeline
-        X (pd.DataFrame, np.ndarray): The input data used to generate a grid of values
+        X (ww.DataTable, pd.DataFrame, np.ndarray): The input data used to generate a grid of values
             for feature where partial dependence will be calculated at
         feature (int, string): The target feature for which to create the partial dependence plot for.
             If feature is an int, it must be the index of the feature to use.
             If feature is a string, it must be a valid column name in X.
+        class_label (string, optional): Name of class to plot for multiclass problems. If None, will plot
+            the partial dependence for each class. This argument does not change behavior for regression or binary
+            classification pipelines. For binary classification, the partial dependence for the positive label will
+            always be displayed. Defaults to None.
 
     Returns:
         pd.DataFrame: pd.DataFrame with averaged predictions for all points in the grid averaged
@@ -468,19 +504,47 @@ def graph_partial_dependence(pipeline, X, feature, grid_resolution=100):
     _go = import_or_raise("plotly.graph_objects", error_msg="Cannot find dependency plotly.graph_objects")
     if jupyter_check():
         import_or_raise("ipywidgets", warning=True)
+    if isinstance(pipeline, evalml.pipelines.MulticlassClassificationPipeline) and class_label is not None:
+        if class_label not in pipeline.classes_:
+            msg = f"Class {class_label} is not one of the classes the pipeline was fit on: {', '.join(list(pipeline.classes_))}"
+            raise ValueError(msg)
 
     part_dep = partial_dependence(pipeline, X, feature=feature, grid_resolution=grid_resolution)
     feature_name = str(feature)
     title = f"Partial Dependence of '{feature_name}'"
     layout = _go.Layout(title={'text': title},
-                        xaxis={'title': f'{feature_name}', 'range': _calculate_axis_range(part_dep['feature_values'])},
-                        yaxis={'title': 'Partial Dependence', 'range': _calculate_axis_range(part_dep['partial_dependence'])})
-    data = []
-    data.append(_go.Scatter(x=part_dep['feature_values'],
+                        xaxis={'title': f'{feature_name}'},
+                        yaxis={'title': 'Partial Dependence'},
+                        showlegend=False)
+    if isinstance(pipeline, evalml.pipelines.MulticlassClassificationPipeline):
+        class_labels = [class_label] if class_label is not None else pipeline.classes_
+        _subplots = import_or_raise("plotly.subplots", error_msg="Cannot find dependency plotly.graph_objects")
+
+        # If the user passes in a value for class_label, we want to create a 1 x 1 subplot or else there would
+        # be an empty column in the plot and it would look awkward
+        rows, cols = ((len(class_labels) + 1) // 2, 2) if len(class_labels) > 1 else (1, len(class_labels))
+
+        # Don't specify share_xaxis and share_yaxis so that we get tickmarks in each subplot
+        fig = _subplots.make_subplots(rows=rows, cols=cols, subplot_titles=class_labels)
+        for i, label in enumerate(class_labels):
+
+            # Plotly trace indexing begins at 1 so we add 1 to i
+            fig.add_trace(_go.Scatter(x=part_dep.loc[part_dep.class_label == label, 'feature_values'],
+                                      y=part_dep.loc[part_dep.class_label == label, 'partial_dependence'],
+                                      line=dict(width=3),
+                                      name=label),
+                          row=(i + 2) // 2, col=(i % 2) + 1)
+        fig.update_layout(layout)
+        fig.update_xaxes(title=f'{feature_name}', range=_calculate_axis_range(part_dep['feature_values']))
+        fig.update_yaxes(range=_calculate_axis_range(part_dep['partial_dependence']))
+    else:
+        trace = _go.Scatter(x=part_dep['feature_values'],
                             y=part_dep['partial_dependence'],
                             name='Partial Dependence',
-                            line=dict(width=3)))
-    return _go.Figure(layout=layout, data=data)
+                            line=dict(width=3))
+        fig = _go.Figure(layout=layout, data=[trace])
+
+    return fig
 
 
 def _calculate_axis_range(arr):
@@ -491,8 +555,31 @@ def _calculate_axis_range(arr):
     return [min_value - margins, max_value + margins]
 
 
-def _get_prediction_vs_actual_data(y_true, y_pred, outlier_threshold):
-    """Helper method to help calculate the y_true and y_pred dataframe, with a column for outliers"""
+def get_prediction_vs_actual_data(y_true, y_pred, outlier_threshold=None):
+    """Combines y_true and y_pred into a single dataframe and adds a column for outliers. Used in `graph_prediction_vs_actual()`.
+
+    Arguments:
+        y_true (pd.Series, ww.DataColumn, or np.ndarray): The real target values of the data
+        y_pred (pd.Series, ww.DataColumn, or np.ndarray): The predicted values outputted by the regression model.
+        outlier_threshold (int, float): A positive threshold for what is considered an outlier value. This value is compared to the absolute difference
+                                 between each value of y_true and y_pred. Values within this threshold will be blue, otherwise they will be yellow.
+                                 Defaults to None
+
+    Returns:
+        pd.DataFrame with the following columns:
+                * `prediction`: Predicted values from regression model.
+                * `actual`: Real target values.
+                * `outlier`: Colors indicating which values are in the threshold for what is considered an outlier value.
+
+    """
+    if outlier_threshold and outlier_threshold <= 0:
+        raise ValueError(f"Threshold must be positive! Provided threshold is {outlier_threshold}")
+
+    y_true = _convert_to_woodwork_structure(y_true)
+    y_true = _convert_woodwork_types_wrapper(y_true.to_series())
+    y_pred = _convert_to_woodwork_structure(y_pred)
+    y_pred = _convert_woodwork_types_wrapper(y_pred.to_series())
+
     predictions = y_pred.reset_index(drop=True)
     actual = y_true.reset_index(drop=True)
     data = pd.concat([pd.Series(predictions),
@@ -509,8 +596,8 @@ def graph_prediction_vs_actual(y_true, y_pred, outlier_threshold=None):
     """Generate a scatter plot comparing the true and predicted values. Used for regression plotting
 
     Arguments:
-        y_true (pd.Series): The real target values of the data
-        y_pred (pd.Series): The predicted values outputted by the regression model.
+        y_true (ww.DataColumn, pd.Series): The real target values of the data
+        y_pred (ww.DataColumn, pd.Series): The predicted values outputted by the regression model.
         outlier_threshold (int, float): A positive threshold for what is considered an outlier value. This value is compared to the absolute difference
                                  between each value of y_true and y_pred. Values within this threshold will be blue, otherwise they will be yellow.
                                  Defaults to None
@@ -526,12 +613,7 @@ def graph_prediction_vs_actual(y_true, y_pred, outlier_threshold=None):
     if outlier_threshold and outlier_threshold <= 0:
         raise ValueError(f"Threshold must be positive! Provided threshold is {outlier_threshold}")
 
-    if not isinstance(y_true, pd.Series):
-        y_true = pd.Series(y_true)
-    if not isinstance(y_pred, pd.Series):
-        y_pred = pd.Series(y_pred)
-
-    df = _get_prediction_vs_actual_data(y_true, y_pred, outlier_threshold)
+    df = get_prediction_vs_actual_data(y_true, y_pred, outlier_threshold)
     data = []
 
     x_axis = _calculate_axis_range(df['prediction'])
@@ -555,3 +637,182 @@ def graph_prediction_vs_actual(y_true, y_pred, outlier_threshold=None):
                                 marker=_go.scatter.Marker(color=color),
                                 name=name))
     return _go.Figure(layout=layout, data=data)
+
+
+def _tree_parse(est, feature_names):
+    children_left = est.tree_.children_left
+    children_right = est.tree_.children_right
+    features = est.tree_.feature
+    thresholds = est.tree_.threshold
+    values = est.tree_.value
+
+    def recurse(i):
+        if children_left[i] == children_right[i]:
+            return {'Value': values[i]}
+        return OrderedDict({
+            'Feature': feature_names[features[i]],
+            'Threshold': thresholds[i],
+            'Value': values[i],
+            'Left_Child': recurse(children_left[i]),
+            'Right_Child': recurse(children_right[i])
+        })
+
+    return recurse(0)
+
+
+def decision_tree_data_from_estimator(estimator, feature_names=None):
+    """Return data for a fitted tree in a restructured format
+
+    Arguments:
+        estimator (ComponentBase): A fitted DecisionTree-based estimator.
+        feature_names (List): A list of feature names to replace column index values.
+
+    Returns:
+        OrderedDict: An OrderedDict of OrderedDicts describing a tree structure
+    """
+    if not estimator.model_family == ModelFamily.DECISION_TREE:
+        raise ValueError("Tree structure reformatting is only supported for decision tree estimators")
+    if not estimator._is_fitted:
+        raise NotFittedError("This DecisionTree estimator is not fitted yet. Call 'fit' with appropriate arguments "
+                             "before using this estimator.")
+    est = estimator._component_obj
+
+    if feature_names:
+        if not isinstance(feature_names, list):
+            feature_names = list(feature_names)
+        if len(feature_names) != est.n_features_:
+            raise ValueError("Length mismatch: Expected features has length {} but got list with length {}"
+                             .format(est.n_features_, len(feature_names)))
+
+    return _tree_parse(est, feature_names)
+
+
+def decision_tree_data_from_pipeline(pipeline_):
+    """Return data for a fitted pipeline with  in a restructured format
+
+    Arguments:
+        pipeline_ (PipelineBase): A pipeline with a DecisionTree-based estimator.
+
+    Returns:
+        OrderedDict: An OrderedDict of OrderedDicts describing a tree structure
+    """
+    if not pipeline_.model_family == ModelFamily.DECISION_TREE:
+        raise ValueError("Tree structure reformatting is only supported for decision tree estimators")
+    if not pipeline_._is_fitted:
+        raise NotFittedError("The DecisionTree estimator associated with this pipeline is not fitted yet. Call 'fit' "
+                             "with appropriate arguments before using this estimator.")
+    est = pipeline_.estimator._component_obj
+    feature_names = pipeline_.input_feature_names[pipeline_.estimator.name]
+
+    return _tree_parse(est, feature_names)
+
+
+def visualize_decision_tree(estimator, max_depth=None, rotate=False, filled=False, filepath=None):
+    """Generate an image visualizing the decision tree
+
+    Arguments:
+        estimator (ComponentBase): A fitted DecisionTree-based estimator.
+        max_depth (int, optional): The depth to which the tree should be displayed. If set to None (as by default),
+        tree is fully generated.
+        rotate (bool, optional): Orient tree left to right rather than top-down.
+        filled (bool, optional): Paint nodes to indicate majority class for classification, extremity of values for
+        regression, or purity of node for multi-output.
+        filepath (str, optional): Path to where the graph should be saved. If set to None (as by default), the graph
+        will not be saved.
+
+    Returns:
+        graphviz.Source: DOT object that can be directly displayed in Jupyter notebooks.
+    """
+    if not estimator.model_family == ModelFamily.DECISION_TREE:
+        raise ValueError("Tree visualizations are only supported for decision tree estimators")
+    if max_depth and (not isinstance(max_depth, int) or not max_depth >= 0):
+        raise ValueError("Unknown value: '{}'. The parameter max_depth has to be a non-negative integer"
+                         .format(max_depth))
+    if not estimator._is_fitted:
+        raise NotFittedError("This DecisionTree estimator is not fitted yet. Call 'fit' with appropriate arguments before using this estimator.")
+
+    est = estimator._component_obj
+
+    graphviz = import_or_raise('graphviz', error_msg='Please install graphviz to visualize trees.')
+
+    graph_format = None
+    if filepath:
+        # Cast to str in case a Path object was passed in
+        filepath = str(filepath)
+        try:
+            f = open(filepath, 'w')
+            f.close()
+        except (IOError, FileNotFoundError):
+            raise ValueError(('Specified filepath is not writeable: {}'.format(filepath)))
+        path_and_name, graph_format = os.path.splitext(filepath)
+        if graph_format:
+            graph_format = graph_format[1:].lower()  # ignore the dot
+            supported_filetypes = graphviz.backend.FORMATS
+            if graph_format not in supported_filetypes:
+                raise ValueError(("Unknown format '{}'. Make sure your format is one of the " +
+                                  "following: {}").format(graph_format, supported_filetypes))
+        else:
+            graph_format = 'pdf'  # If the filepath has no extension default to pdf
+
+    dot_data = export_graphviz(decision_tree=est, max_depth=max_depth, rotate=rotate, filled=filled)
+    source_obj = graphviz.Source(source=dot_data, format=graph_format)
+    if filepath:
+        source_obj.render(filename=path_and_name, cleanup=True)
+
+    return source_obj
+
+
+def get_prediction_vs_actual_over_time_data(pipeline, X, y, dates):
+    """Get the data needed for the prediction_vs_actual_over_time plot.
+
+    Arguments:
+        pipeline (TimeSeriesRegressionPipeline): Fitted time series regression pipeline.
+        X (ww.DataTable, pd.DataFrame): Features used to generate new predictions.
+        y (ww.DataColumn, pd.Series): Target values to compare predictions against.
+        dates (ww.DataColumn, pd.Series): Dates corresponding to target values and predictions.
+
+    Returns:
+       pd.DataFrame
+    """
+
+    dates = _convert_to_woodwork_structure(dates)
+    y = _convert_to_woodwork_structure(y)
+    prediction = pipeline.predict(X, y)
+
+    dates = _convert_woodwork_types_wrapper(dates.to_series())
+    y = _convert_woodwork_types_wrapper(y.to_series())
+    return pd.DataFrame({"dates": dates.reset_index(drop=True),
+                         "target": y.reset_index(drop=True),
+                         "prediction": prediction.reset_index(drop=True)})
+
+
+def graph_prediction_vs_actual_over_time(pipeline, X, y, dates):
+    """Plot the target values and predictions against time on the x-axis.
+
+    Arguments:
+        pipeline (TimeSeriesRegressionPipeline): Fitted time series regression pipeline.
+        X (ww.DataTable, pd.DataFrame): Features used to generate new predictions.
+        y (ww.DataColumn, pd.Series): Target values to compare predictions against.
+        dates (ww.DataColumn, pd.Series): Dates corresponding to target values and predictions.
+
+    Returns:
+        plotly.Figure showing the prediction vs actual over time.
+    """
+    _go = import_or_raise("plotly.graph_objects", error_msg="Cannot find dependency plotly.graph_objects")
+
+    if pipeline.problem_type != ProblemTypes.TIME_SERIES_REGRESSION:
+        raise ValueError("graph_prediction_vs_actual_over_time only supports time series regression pipelines! "
+                         f"Received {str(pipeline.problem_type)}.")
+
+    data = get_prediction_vs_actual_over_time_data(pipeline, X, y, dates)
+
+    data = [_go.Scatter(x=data["dates"], y=data["target"], mode='lines+markers', name="Target",
+                        line=dict(color='#1f77b4')),
+            _go.Scatter(x=data["dates"], y=data["prediction"], mode='lines+markers', name='Prediction',
+                        line=dict(color='#d62728'))]
+    # Let plotly pick the best date format.
+    layout = _go.Layout(title={'text': "Prediction vs Target over time"},
+                        xaxis={'title': 'Time'},
+                        yaxis={'title': 'Target Values and Predictions'})
+
+    return _go.Figure(data=data, layout=layout)
