@@ -7,6 +7,7 @@ from .components import (
     StandardScaler,
     Transformer,
     LightGBMClassifier,
+    LightGBMRegressor,
     LinearRegressor,
     LogisticRegressionClassifier,
     RandomForestClassifier,
@@ -26,25 +27,30 @@ from .components import (
     DecisionTreeRegressor,
     StackedEnsembleClassifier,
     StackedEnsembleRegressor,
-    DelayedFeatureTransformer
+    DelayedFeatureTransformer,
+    DFSTransformer
 )
 
+from .component_graph import ComponentGraph
 from .pipeline_base import PipelineBase
 from .classification_pipeline import ClassificationPipeline
 from .binary_classification_pipeline import BinaryClassificationPipeline
 from .multiclass_classification_pipeline import MulticlassClassificationPipeline
 from .regression_pipeline import RegressionPipeline
-
+from .time_series_classification_pipelines import (
+    TimeSeriesClassificationPipeline,
+    TimeSeriesBinaryClassificationPipeline,
+    TimeSeriesMulticlassClassificationPipeline
+)
 from .classification import (
     BaselineBinaryPipeline,
     BaselineMulticlassPipeline,
     ModeBaselineBinaryPipeline,
     ModeBaselineMulticlassPipeline
 )
-
+from .time_series_regression_pipeline import TimeSeriesRegressionPipeline
 from .regression import (
     BaselineRegressionPipeline,
-    MeanBaselineRegressionPipeline
+    MeanBaselineRegressionPipeline,
+    TimeSeriesBaselineRegressionPipeline
 )
-
-from .time_series_regression_pipeline import TimeSeriesRegressionPipeline
