@@ -3,6 +3,7 @@ from .estimators import (
     Estimator,
     LinearRegressor,
     LightGBMClassifier,
+    LightGBMRegressor,
     LogisticRegressionClassifier,
     RandomForestClassifier,
     RandomForestRegressor,
@@ -17,7 +18,8 @@ from .estimators import (
     BaselineClassifier,
     BaselineRegressor,
     DecisionTreeClassifier,
-    DecisionTreeRegressor
+    DecisionTreeRegressor,
+    TimeSeriesBaselineRegressor
 )
 from .transformers import (
     Transformer,
@@ -36,8 +38,10 @@ from .transformers import (
     DateTimeFeaturizer,
     SelectColumns,
     TextFeaturizer,
+    LinearDiscriminantAnalysis,
     LSA,
-    PCA
+    PCA,
+    DFSTransformer
 )
 from .ensemble import (
     StackedEnsembleClassifier,
