@@ -9,10 +9,12 @@ from .classifiers import (LogisticRegressionClassifier,
                           BaselineClassifier,
                           DecisionTreeClassifier)
 from .regressors import (LinearRegressor,
+                         LightGBMRegressor,
                          RandomForestRegressor,
                          CatBoostRegressor,
                          XGBoostRegressor,
                          ElasticNetRegressor,
                          ExtraTreesRegressor,
                          BaselineRegressor,
+                         TimeSeriesBaselineRegressor,
                          DecisionTreeRegressor)
