@@ -15,7 +15,8 @@ class ExtraTreesClassifier(Estimator):
         "max_depth": Integer(4, 10)
     }
     model_family = ModelFamily.EXTRA_TREES
-    supported_problem_types = [ProblemTypes.BINARY, ProblemTypes.MULTICLASS]
+    supported_problem_types = [ProblemTypes.BINARY, ProblemTypes.MULTICLASS,
+                               ProblemTypes.TIME_SERIES_BINARY, ProblemTypes.TIME_SERIES_MULTICLASS]
 
     def __init__(self,
                  n_estimators=100,
