@@ -14,7 +14,8 @@ class RandomForestClassifier(Estimator):
         "max_depth": Integer(1, 10),
     }
     model_family = ModelFamily.RANDOM_FOREST
-    supported_problem_types = [ProblemTypes.BINARY, ProblemTypes.MULTICLASS]
+    supported_problem_types = [ProblemTypes.BINARY, ProblemTypes.MULTICLASS,
+                               ProblemTypes.TIME_SERIES_BINARY, ProblemTypes.TIME_SERIES_MULTICLASS]
 
     def __init__(self, n_estimators=100, max_depth=6, n_jobs=-1, random_state=0, **kwargs):
         parameters = {"n_estimators": n_estimators,
