@@ -1,8 +1,10 @@
 from .elasticnet_regressor import ElasticNetRegressor
 from .linear_regressor import LinearRegressor
+from .lightgbm_regressor import LightGBMRegressor
 from .rf_regressor import RandomForestRegressor
 from .catboost_regressor import CatBoostRegressor
 from .xgboost_regressor import XGBoostRegressor
 from .et_regressor import ExtraTreesRegressor
 from .baseline_regressor import BaselineRegressor
 from .decision_tree_regressor import DecisionTreeRegressor
+from .time_series_baseline_regressor import TimeSeriesBaselineRegressor
