@@ -1,13 +1,15 @@
 import copy
 
-import pandas as pd
 from skopt.space import Integer, Real
 
 from evalml.model_family import ModelFamily
 from evalml.pipelines.components.estimators import Estimator
 from evalml.problem_types import ProblemTypes
 from evalml.utils import SEED_BOUNDS, get_random_seed, import_or_raise
-from evalml.utils.gen_utils import categorical_dtypes
+from evalml.utils.gen_utils import (
+    _convert_to_woodwork_structure,
+    _convert_woodwork_types_wrapper
+)
 
 
 class CatBoostRegressor(Estimator):
@@ -24,7 +26,7 @@ class CatBoostRegressor(Estimator):
         "max_depth": Integer(4, 10),
     }
     model_family = ModelFamily.CATBOOST
-    supported_problem_types = [ProblemTypes.REGRESSION]
+    supported_problem_types = [ProblemTypes.REGRESSION, ProblemTypes.TIME_SERIES_REGRESSION]
 
     SEED_MIN = 0
     SEED_MAX = SEED_BOUNDS.max_bound
@@ -53,11 +55,13 @@ class CatBoostRegressor(Estimator):
                          random_state=random_state)
 
     def fit(self, X, y=None):
-        if not isinstance(X, pd.DataFrame):
-            X = pd.DataFrame(X)
-        if not isinstance(y, pd.Series):
-            y = pd.Series(y)
-        cat_cols = X.select_dtypes(categorical_dtypes)
+        X = _convert_to_woodwork_structure(X)
+        cat_cols = list(X.select('category').columns)
+        X = _convert_woodwork_types_wrapper(X.to_dataframe())
+
+        y = _convert_to_woodwork_structure(y)
+        y = _convert_woodwork_types_wrapper(y.to_series())
+
         model = self._component_obj.fit(X, y, silent=True, cat_features=cat_cols)
         return model
 
