@@ -6,20 +6,38 @@ from evalml.utils.gen_utils import (
 )
 
 
-def _extract_year(col):
-    return col.dt.year
+def _extract_year(col, encode_as_categories=False):
+    return col.dt.year, None
 
 
-def _extract_month(col):
-    return col.dt.month_name().astype('category')
+_month_to_int_mapping = {"January": 0, "February": 1, "March": 2, "April": 3, "May": 4, "June": 5,
+                         "July": 6, "August": 7, "September": 8, "October": 9, "November": 10, "December": 11}
 
 
-def _extract_day_of_week(col):
-    return col.dt.day_name().astype('category')
+def _extract_month(col, encode_as_categories=False):
+    months = col.dt.month_name()
+    months_unique = months.unique()
+    months_encoded = months.map(lambda m: _month_to_int_mapping[m])
+    if encode_as_categories:
+        months_encoded = months_encoded.astype("category")
+    return months_encoded, {m: _month_to_int_mapping[m] for m in months_unique}
 
 
-def _extract_hour(col):
-    return col.dt.hour
+_day_to_int_mapping = {"Sunday": 0, "Monday": 1, "Tuesday": 2, "Wednesday": 3, "Thursday": 4, "Friday": 5,
+                       "Saturday": 6}
+
+
+def _extract_day_of_week(col, encode_as_categories=False):
+    days = col.dt.day_name()
+    days_unique = days.unique()
+    days_encoded = days.map(lambda d: _day_to_int_mapping[d])
+    if encode_as_categories:
+        days_encoded = days_encoded.astype("category")
+    return days_encoded, {d: _day_to_int_mapping[d] for d in days_unique}
+
+
+def _extract_hour(col, encode_as_categories=False):
+    return col.dt.hour, None
 
 
 class DateTimeFeaturizer(Transformer):
@@ -31,11 +49,13 @@ class DateTimeFeaturizer(Transformer):
                           "day_of_week": _extract_day_of_week,
                           "hour": _extract_hour}
 
-    def __init__(self, features_to_extract=None, random_state=0, **kwargs):
+    def __init__(self, features_to_extract=None, encode_as_categories=False, random_state=0, **kwargs):
         """Extracts features from DateTime columns
 
         Arguments:
             features_to_extract (list): List of features to extract. Valid options include "year", "month", "day_of_week", "hour".
+            encode_as_categories (bool): Whether day-of-week and month features should be encoded as pandas "category" dtype.
+                This allows OneHotEncoders to encode these features.
             random_state (int, np.random.RandomState): Seed for the random number generator.
         """
         if features_to_extract is None:
@@ -44,10 +64,13 @@ class DateTimeFeaturizer(Transformer):
         if len(invalid_features) > 0:
             raise ValueError("{} are not valid options for features_to_extract".format(", ".join([f"'{feature}'" for feature in invalid_features])))
 
-        parameters = {"features_to_extract": features_to_extract}
+        parameters = {"features_to_extract": features_to_extract,
+                      "encode_as_categories": encode_as_categories}
         parameters.update(kwargs)
 
         self._date_time_col_names = None
+        self._categories = {}
+        self.encode_as_categories = encode_as_categories
         super().__init__(parameters=parameters,
                          component_obj=None,
                          random_state=random_state)
@@ -76,5 +99,18 @@ class DateTimeFeaturizer(Transformer):
             return X_t
         for col_name in self._date_time_col_names:
             for feature in features_to_extract:
-                X_t[f"{col_name}_{feature}"] = self._function_mappings[feature](X_t[col_name])
+                name = f"{col_name}_{feature}"
+                features, categories = self._function_mappings[feature](X_t[col_name], self.encode_as_categories)
+                X_t[name] = features
+                if categories:
+                    self._categories[name] = categories
         return X_t.drop(self._date_time_col_names, axis=1)
+
+    def get_feature_names(self):
+        """Gets the categories of each datetime feature.
+
+        Returns:
+           Dict. Each key-value pair is a column name and a dictionary mapping the unique feature values to their
+           integer encoding.
+        """
+        return self._categories
