@@ -1,2 +1,2 @@
-# flake8:noqa
 from .baseline_regression import BaselineRegressionPipeline, MeanBaselineRegressionPipeline
+from .time_series_baseline_regression import TimeSeriesBaselineRegressionPipeline
