@@ -5,6 +5,10 @@ from .multiclass_classification_pipeline import (
     MulticlassClassificationPipeline
 )
 from .regression_pipeline import RegressionPipeline
+from .time_series_classification_pipelines import (
+    TimeSeriesBinaryClassificationPipeline,
+    TimeSeriesMulticlassClassificationPipeline
+)
 from .time_series_regression_pipeline import TimeSeriesRegressionPipeline
 
 from evalml.model_family import ModelFamily
@@ -82,6 +86,10 @@ def _get_pipeline_base_class(problem_type):
         return RegressionPipeline
     elif problem_type == ProblemTypes.TIME_SERIES_REGRESSION:
         return TimeSeriesRegressionPipeline
+    elif problem_type == ProblemTypes.TIME_SERIES_BINARY:
+        return TimeSeriesBinaryClassificationPipeline
+    else:
+        return TimeSeriesMulticlassClassificationPipeline
 
 
 def make_pipeline(X, y, estimator, problem_type, custom_hyperparameters=None, text_columns=None):
@@ -174,11 +182,13 @@ def generate_pipeline_code(element):
         Does not include code for custom component implementation.
     """
     # hold the imports needed and add code to end
-    code_strings = []
+    code_strings = ['import json']
     if not isinstance(element, PipelineBase):
         raise ValueError("Element must be a pipeline instance, received {}".format(type(element)))
+    if isinstance(element.component_graph, dict):
+        raise ValueError("Code generation for nonlinear pipelines is not supported yet")
 
-    component_graph_string = ',\n\t\t'.join([com.__class__.__name__ if com.__class__ not in all_components() else "'{}'".format(com.name) for com in element.component_graph])
+    component_graph_string = ',\n\t\t'.join([com.__class__.__name__ if com.__class__ not in all_components() else "'{}'".format(com.name) for com in element._component_graph])
     code_strings.append("from {} import {}".format(element.__class__.__bases__[0].__module__, element.__class__.__bases__[0].__name__))
     # check for other attributes associated with pipeline (ie name, custom_hyperparameters)
     pipeline_list = []
@@ -188,17 +198,22 @@ def generate_pipeline_code(element):
         pipeline_list += ["{} = '{}'".format(k, v)] if isinstance(v, str) else ["{} = {}".format(k, v)]
 
     pipeline_string = "\t" + "\n\t".join(pipeline_list) + "\n" if len(pipeline_list) else ""
+
+    try:
+        ret = json.dumps(element.parameters, indent='\t')
+    except TypeError:
+        raise TypeError(f"Value {element.parameters} cannot be JSON-serialized")
     # create the base string for the pipeline
     base_string = "\nclass {0}({1}):\n" \
                   "\tcomponent_graph = [\n\t\t{2}\n\t]\n" \
                   "{3}" \
-                  "\nparameters = {4}\n" \
+                  "\nparameters = json.loads(\"\"\"{4}\"\"\")\n" \
                   "pipeline = {0}(parameters)" \
                   .format(element.__class__.__name__,
                           element.__class__.__bases__[0].__name__,
                           component_graph_string,
                           pipeline_string,
-                          json.dumps(element.parameters, indent='\t').replace('null', 'None'))
+                          ret)
     code_strings.append(base_string)
     return "\n".join(code_strings)
 
