@@ -20,6 +20,7 @@ from evalml.objectives import (
 )
 from evalml.pipelines import (
     ModeBaselineBinaryPipeline,
+    ModeBaselineMulticlassPipeline,
     MulticlassClassificationPipeline,
     PipelineBase
 )
@@ -31,48 +32,54 @@ from evalml.problem_types import ProblemTypes
 def test_init(X_y_binary):
     X, y = X_y_binary
 
-    automl = AutoMLSearch(problem_type='binary', max_iterations=1, n_jobs=4)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', max_iterations=1, n_jobs=1)
+    automl.search()
 
-    assert automl.n_jobs == 4
+    assert automl.n_jobs == 1
     assert isinstance(automl.rankings, pd.DataFrame)
     assert isinstance(automl.best_pipeline, PipelineBase)
+    automl.best_pipeline.predict(X)
 
     # test with dataframes
-    automl = AutoMLSearch(problem_type='binary', max_iterations=1, n_jobs=4)
-    automl.search(pd.DataFrame(X), pd.Series(y))
+    automl = AutoMLSearch(pd.DataFrame(X), pd.Series(y), problem_type='binary', max_iterations=1, n_jobs=1)
+    automl.search()
 
     assert isinstance(automl.rankings, pd.DataFrame)
     assert isinstance(automl.full_rankings, pd.DataFrame)
     assert isinstance(automl.best_pipeline, PipelineBase)
     assert isinstance(automl.get_pipeline(0), PipelineBase)
     assert automl.objective.name == 'Log Loss Binary'
+    automl.best_pipeline.predict(X)
 
 
-def test_init_objective():
-    automl = AutoMLSearch(problem_type='binary', objective=Precision(), max_iterations=1)
+def test_init_objective(X_y_binary):
+    X, y = X_y_binary
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective=Precision(), max_iterations=1)
     assert isinstance(automl.objective, Precision)
-    automl = AutoMLSearch(problem_type='binary', objective='Precision', max_iterations=1)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective='Precision', max_iterations=1)
     assert isinstance(automl.objective, Precision)
 
 
-def test_get_pipeline_none():
-    automl = AutoMLSearch(problem_type='binary')
+def test_get_pipeline_none(X_y_binary):
+    X, y = X_y_binary
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary')
     with pytest.raises(PipelineNotFoundError, match="Pipeline not found"):
         automl.describe_pipeline(0)
 
 
-def test_data_split(X_y_binary):
+def test_data_splitter(X_y_binary):
     X, y = X_y_binary
     cv_folds = 5
-    automl = AutoMLSearch(problem_type='binary', data_split=StratifiedKFold(cv_folds), max_iterations=1)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', data_splitter=StratifiedKFold(cv_folds), max_iterations=1,
+                          n_jobs=1)
+    automl.search()
 
     assert isinstance(automl.rankings, pd.DataFrame)
     assert len(automl.results['pipeline_results'][0]["cv_data"]) == cv_folds
 
-    automl = AutoMLSearch(problem_type='binary', data_split=TimeSeriesSplit(cv_folds), max_iterations=1)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', data_splitter=TimeSeriesSplit(cv_folds), max_iterations=1,
+                          n_jobs=1)
+    automl.search()
 
     assert isinstance(automl.rankings, pd.DataFrame)
     assert len(automl.results['pipeline_results'][0]["cv_data"]) == cv_folds
@@ -81,8 +88,8 @@ def test_data_split(X_y_binary):
 def test_max_iterations(X_y_binary):
     X, y = X_y_binary
     max_iterations = 5
-    automl = AutoMLSearch(problem_type='binary', max_iterations=max_iterations)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', max_iterations=max_iterations, n_jobs=1)
+    automl.search()
     assert len(automl.full_rankings) == max_iterations
 
 
@@ -91,24 +98,24 @@ def test_recall_error(X_y_binary):
     # Recall is a valid objective but it's not allowed in AutoML so a ValueError is expected
     error_msg = 'recall is not allowed in AutoML!'
     with pytest.raises(ValueError, match=error_msg):
-        AutoMLSearch(problem_type='binary', objective='recall', max_iterations=1)
+        AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective='recall', max_iterations=1)
 
 
 def test_recall_object(X_y_binary):
     X, y = X_y_binary
-    automl = AutoMLSearch(problem_type='binary', objective=Recall(), max_iterations=1)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective=Recall(), max_iterations=1, n_jobs=1)
+    automl.search()
     assert len(automl.full_rankings) > 0
     assert automl.objective.name == 'Recall'
 
 
 def test_binary_auto(X_y_binary):
     X, y = X_y_binary
-    automl = AutoMLSearch(problem_type='binary', objective="Log Loss Binary", max_iterations=5)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective="Log Loss Binary", max_iterations=5, n_jobs=1)
+    automl.search()
 
     best_pipeline = automl.best_pipeline
-    best_pipeline.fit(X, y)
+    assert best_pipeline._is_fitted
     y_pred = best_pipeline.predict(X)
     assert len(np.unique(y_pred)) == 2
 
@@ -116,10 +123,10 @@ def test_binary_auto(X_y_binary):
 def test_multi_auto(X_y_multi, multiclass_core_objectives):
     X, y = X_y_multi
     objective = PrecisionMicro()
-    automl = AutoMLSearch(problem_type='multiclass', objective=objective, max_iterations=5)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='multiclass', objective=objective, max_iterations=5, n_jobs=1)
+    automl.search()
     best_pipeline = automl.best_pipeline
-    best_pipeline.fit(X, y)
+    assert best_pipeline._is_fitted
     y_pred = best_pipeline.predict(X)
     assert len(np.unique(y_pred)) == 3
 
@@ -131,40 +138,41 @@ def test_multi_auto(X_y_multi, multiclass_core_objectives):
 
 
 def test_multi_objective(X_y_multi):
-    automl = AutoMLSearch(problem_type='binary', objective="Log Loss Binary")
+    X, y = X_y_multi
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective="Log Loss Binary")
     assert automl.problem_type == ProblemTypes.BINARY
 
-    automl = AutoMLSearch(problem_type='multiclass', objective="Log Loss Multiclass")
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='multiclass', objective="Log Loss Multiclass")
     assert automl.problem_type == ProblemTypes.MULTICLASS
 
-    automl = AutoMLSearch(problem_type='multiclass', objective='AUC Micro')
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='multiclass', objective='AUC Micro')
     assert automl.problem_type == ProblemTypes.MULTICLASS
 
-    automl = AutoMLSearch(problem_type='binary', objective='AUC')
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective='AUC')
     assert automl.problem_type == ProblemTypes.BINARY
 
-    automl = AutoMLSearch(problem_type='multiclass')
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='multiclass')
     assert automl.problem_type == ProblemTypes.MULTICLASS
 
-    automl = AutoMLSearch(problem_type='binary')
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary')
     assert automl.problem_type == ProblemTypes.BINARY
 
 
 def test_categorical_classification(X_y_categorical_classification):
     X, y = X_y_categorical_classification
-    automl = AutoMLSearch(problem_type='binary', objective="precision", max_iterations=5)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective="precision", max_iterations=5, n_jobs=1)
+    automl.search()
     assert not automl.rankings['score'].isnull().all()
 
 
 def test_random_state(X_y_binary):
     X, y = X_y_binary
 
-    automl = AutoMLSearch(problem_type='binary', objective=Precision(), max_iterations=5, random_state=0)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective=Precision(), max_iterations=5, random_state=0, n_jobs=1)
+    automl.search()
 
-    automl_1 = AutoMLSearch(problem_type='binary', objective=Precision(), max_iterations=5, random_state=0)
-    automl_1.search(X, y)
+    automl_1 = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective=Precision(), max_iterations=5, random_state=0, n_jobs=1)
+    automl_1.search()
     assert automl.rankings.equals(automl_1.rankings)
 
 
@@ -183,10 +191,11 @@ def test_callback(X_y_binary):
         counts["add_result_callback"] += 1
 
     max_iterations = 3
-    automl = AutoMLSearch(problem_type='binary', objective=Precision(), max_iterations=max_iterations,
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective=Precision(), max_iterations=max_iterations,
                           start_iteration_callback=start_iteration_callback,
-                          add_result_callback=add_result_callback)
-    automl.search(X, y)
+                          add_result_callback=add_result_callback,
+                          n_jobs=1)
+    automl.search()
 
     assert counts["start_iteration_callback"] == max_iterations
     assert counts["add_result_callback"] == max_iterations
@@ -199,8 +208,9 @@ def test_additional_objectives(X_y_binary):
                           interchange_fee=.02,
                           fraud_payout_percentage=.75,
                           amount_col=10)
-    automl = AutoMLSearch(problem_type='binary', objective='F1', max_iterations=2, additional_objectives=[objective])
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective='F1', max_iterations=2, additional_objectives=[objective],
+                          n_jobs=1)
+    automl.search()
 
     results = automl.describe_pipeline(0, return_dict=True)
     assert 'Fraud Cost' in list(results["cv_data"][0]["all_objective_scores"].keys())
@@ -213,14 +223,14 @@ def test_additional_objectives(X_y_binary):
 def test_optimizable_threshold_enabled(mock_fit, mock_score, mock_predict_proba, mock_optimize_threshold, X_y_binary, caplog):
     mock_optimize_threshold.return_value = 0.8
     X, y = X_y_binary
-    automl = AutoMLSearch(problem_type='binary', objective='precision', max_iterations=1, optimize_thresholds=True)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective='precision', max_iterations=1, optimize_thresholds=True)
     mock_score.return_value = {automl.objective.name: 1.0}
-    automl.search(X, y)
+    automl.search()
     mock_fit.assert_called()
     mock_score.assert_called()
     mock_predict_proba.assert_called()
     mock_optimize_threshold.assert_called()
-    assert automl.best_pipeline.threshold is None
+    assert automl.best_pipeline.threshold is not None
     assert automl.results['pipeline_results'][0]['cv_data'][0].get('binary_classification_threshold') == 0.8
     assert automl.results['pipeline_results'][0]['cv_data'][1].get('binary_classification_threshold') == 0.8
     assert automl.results['pipeline_results'][0]['cv_data'][2].get('binary_classification_threshold') == 0.8
@@ -237,14 +247,14 @@ def test_optimizable_threshold_enabled(mock_fit, mock_score, mock_predict_proba,
 def test_optimizable_threshold_disabled(mock_fit, mock_score, mock_predict_proba, mock_optimize_threshold, X_y_binary):
     mock_optimize_threshold.return_value = 0.8
     X, y = X_y_binary
-    automl = AutoMLSearch(problem_type='binary', objective='precision', max_iterations=1, optimize_thresholds=False)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective='precision', max_iterations=1, optimize_thresholds=False)
     mock_score.return_value = {automl.objective.name: 1.0}
-    automl.search(X, y)
+    automl.search()
     mock_fit.assert_called()
     mock_score.assert_called()
     assert not mock_predict_proba.called
     assert not mock_optimize_threshold.called
-    assert automl.best_pipeline.threshold is None
+    assert automl.best_pipeline.threshold is not None
     assert automl.results['pipeline_results'][0]['cv_data'][0].get('binary_classification_threshold') == 0.5
     assert automl.results['pipeline_results'][0]['cv_data'][1].get('binary_classification_threshold') == 0.5
     assert automl.results['pipeline_results'][0]['cv_data'][2].get('binary_classification_threshold') == 0.5
@@ -255,11 +265,11 @@ def test_optimizable_threshold_disabled(mock_fit, mock_score, mock_predict_proba
 def test_non_optimizable_threshold(mock_fit, mock_score, X_y_binary):
     mock_score.return_value = {"AUC": 1.0}
     X, y = X_y_binary
-    automl = AutoMLSearch(problem_type='binary', objective='AUC', max_iterations=1)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective='AUC', max_iterations=1)
+    automl.search()
     mock_fit.assert_called()
     mock_score.assert_called()
-    assert automl.best_pipeline.threshold is None
+    assert automl.best_pipeline.threshold is not None
     assert automl.results['pipeline_results'][0]['cv_data'][0].get('binary_classification_threshold') == 0.5
     assert automl.results['pipeline_results'][0]['cv_data'][1].get('binary_classification_threshold') == 0.5
     assert automl.results['pipeline_results'][0]['cv_data'][2].get('binary_classification_threshold') == 0.5
@@ -267,8 +277,8 @@ def test_non_optimizable_threshold(mock_fit, mock_score, X_y_binary):
 
 def test_describe_pipeline_objective_ordered(X_y_binary, caplog):
     X, y = X_y_binary
-    automl = AutoMLSearch(problem_type='binary', objective='AUC', max_iterations=2)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective='AUC', max_iterations=2, n_jobs=1)
+    automl.search()
 
     automl.describe_pipeline(0)
     out = caplog.text
@@ -281,34 +291,38 @@ def test_describe_pipeline_objective_ordered(X_y_binary, caplog):
     assert expected_objective_order in out_stripped
 
 
-def test_max_time_units():
-    str_max_time = AutoMLSearch(problem_type='binary', objective='F1', max_time='60 seconds')
+def test_max_time_units(X_y_binary):
+    X, y = X_y_binary
+    str_max_time = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective='F1', max_time='60 seconds')
     assert str_max_time.max_time == 60
 
-    hour_max_time = AutoMLSearch(problem_type='binary', objective='F1', max_time='1 hour')
+    hour_max_time = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective='F1', max_time='1 hour')
     assert hour_max_time.max_time == 3600
 
-    min_max_time = AutoMLSearch(problem_type='binary', objective='F1', max_time='30 mins')
+    min_max_time = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective='F1', max_time='30 mins')
     assert min_max_time.max_time == 1800
 
-    min_max_time = AutoMLSearch(problem_type='binary', objective='F1', max_time='30 s')
+    min_max_time = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective='F1', max_time='30 s')
     assert min_max_time.max_time == 30
 
     with pytest.raises(AssertionError, match="Invalid unit. Units must be hours, mins, or seconds. Received 'year'"):
-        AutoMLSearch(problem_type='binary', objective='F1', max_time='30 years')
+        AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective='F1', max_time='30 years')
 
     with pytest.raises(TypeError, match="Parameter max_time must be a float, int, string or None. Received <class 'tuple'> with value \\(30, 'minutes'\\)."):
-        AutoMLSearch(problem_type='binary', objective='F1', max_time=(30, 'minutes'))
+        AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective='F1', max_time=(30, 'minutes'))
 
 
-def test_early_stopping(caplog, logistic_regression_binary_pipeline_class):
+def test_early_stopping(caplog, logistic_regression_binary_pipeline_class, X_y_binary):
+    X, y = X_y_binary
     with pytest.raises(ValueError, match='patience value must be a positive integer.'):
-        automl = AutoMLSearch(problem_type='binary', objective='AUC', max_iterations=5, allowed_model_families=['linear_model'], patience=-1, random_state=0)
+        automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective='AUC', max_iterations=5, allowed_model_families=['linear_model'], patience=-1, random_state=0)
 
     with pytest.raises(ValueError, match='tolerance value must be'):
-        automl = AutoMLSearch(problem_type='binary', objective='AUC', max_iterations=5, allowed_model_families=['linear_model'], patience=1, tolerance=1.5, random_state=0)
+        automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective='AUC', max_iterations=5, allowed_model_families=['linear_model'], patience=1, tolerance=1.5, random_state=0)
 
-    automl = AutoMLSearch(problem_type='binary', objective='AUC', max_iterations=5, allowed_model_families=['linear_model'], patience=2, tolerance=0.05, random_state=0)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective='AUC', max_iterations=5,
+                          allowed_model_families=['linear_model'], patience=2, tolerance=0.05,
+                          random_state=0, n_jobs=1)
     mock_results = {
         'search_order': [0, 1, 2],
         'pipeline_results': {}
@@ -329,7 +343,7 @@ def test_early_stopping(caplog, logistic_regression_binary_pipeline_class):
 def test_plot_disabled_missing_dependency(X_y_binary, has_minimal_dependencies):
     X, y = X_y_binary
 
-    automl = AutoMLSearch(problem_type='binary', max_iterations=3)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', max_iterations=3)
     if has_minimal_dependencies:
         with pytest.raises(AttributeError):
             automl.plot.search_iteration_plot
@@ -341,8 +355,8 @@ def test_plot_iterations_max_iterations(X_y_binary):
     go = pytest.importorskip('plotly.graph_objects', reason='Skipping plotting test because plotly not installed')
     X, y = X_y_binary
 
-    automl = AutoMLSearch(problem_type='binary', objective="f1", max_iterations=3)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective="f1", max_iterations=3, n_jobs=1)
+    automl.search()
     plot = automl.plot.search_iteration_plot()
     plot_data = plot.data[0]
     x = pd.Series(plot_data['x'])
@@ -359,8 +373,8 @@ def test_plot_iterations_max_time(X_y_binary):
     go = pytest.importorskip('plotly.graph_objects', reason='Skipping plotting test because plotly not installed')
     X, y = X_y_binary
 
-    automl = AutoMLSearch(problem_type='binary', objective="f1", max_time=10)
-    automl.search(X, y, show_iteration_plot=False)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective="f1", max_time=10, n_jobs=1)
+    automl.search(show_iteration_plot=False)
     plot = automl.plot.search_iteration_plot()
     plot_data = plot.data[0]
     x = pd.Series(plot_data['x'])
@@ -379,8 +393,8 @@ def test_plot_iterations_ipython_mock(mock_ipython_display, X_y_binary):
     pytest.importorskip('plotly.graph_objects', reason='Skipping plotting test because plotly not installed')
     X, y = X_y_binary
 
-    automl = AutoMLSearch(problem_type='binary', objective="f1", max_iterations=3)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective="f1", max_iterations=3, n_jobs=1)
+    automl.search()
     plot = automl.plot.search_iteration_plot(interactive_plot=True)
     assert isinstance(plot, SearchIterationPlot)
     assert isinstance(plot.data, AutoMLSearch)
@@ -393,8 +407,8 @@ def test_plot_iterations_ipython_mock_import_failure(mock_ipython_display, X_y_b
     go = pytest.importorskip('plotly.graph_objects', reason='Skipping plotting test because plotly not installed')
     X, y = X_y_binary
 
-    automl = AutoMLSearch(problem_type='binary', objective="f1", max_iterations=3)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective="f1", max_iterations=3, n_jobs=1)
+    automl.search()
 
     mock_ipython_display.side_effect = ImportError('KABOOOOOOMMMM')
     plot = automl.plot.search_iteration_plot(interactive_plot=True)
@@ -413,10 +427,10 @@ def test_plot_iterations_ipython_mock_import_failure(mock_ipython_display, X_y_b
 
 def test_max_time(X_y_binary):
     X, y = X_y_binary
-    clf = AutoMLSearch(problem_type='binary', max_time=1e-16)
-    clf.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', max_time=1e-16, n_jobs=1)
+    automl.search()
     # search will always run at least one pipeline
-    assert len(clf.results['pipeline_results']) == 1
+    assert len(automl.results['pipeline_results']) == 1
 
 
 @pytest.mark.parametrize("automl_type", [ProblemTypes.BINARY, ProblemTypes.MULTICLASS])
@@ -424,23 +438,23 @@ def test_automl_allowed_pipelines_no_allowed_pipelines(automl_type, X_y_binary,
     is_multiclass = automl_type == ProblemTypes.MULTICLASS
     X, y = X_y_multi if is_multiclass else X_y_binary
     problem_type = 'multiclass' if is_multiclass else 'binary'
-    automl = AutoMLSearch(problem_type=problem_type, allowed_pipelines=None, allowed_model_families=[])
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type=problem_type, allowed_pipelines=None, allowed_model_families=[])
     assert automl.allowed_pipelines is None
     with pytest.raises(ValueError, match="No allowed pipelines to search"):
-        automl.search(X, y)
+        automl.search()
 
 
 @patch('evalml.pipelines.BinaryClassificationPipeline.score')
 @patch('evalml.pipelines.BinaryClassificationPipeline.fit')
 def test_automl_allowed_pipelines_specified_allowed_pipelines_binary(mock_fit, mock_score, dummy_binary_pipeline_class, X_y_binary):
     X, y = X_y_binary
-    automl = AutoMLSearch(problem_type='binary', allowed_pipelines=[dummy_binary_pipeline_class], allowed_model_families=None)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', allowed_pipelines=[dummy_binary_pipeline_class], allowed_model_families=None)
     expected_pipelines = [dummy_binary_pipeline_class]
     mock_score.return_value = {automl.objective.name: 1.0}
     assert automl.allowed_pipelines == expected_pipelines
     assert automl.allowed_model_families is None
 
-    automl.search(X, y)
+    automl.search()
     mock_fit.assert_called()
     mock_score.assert_called()
     assert automl.allowed_pipelines == expected_pipelines
@@ -451,13 +465,13 @@ def test_automl_allowed_pipelines_specified_allowed_pipelines_binary(mock_fit, m
 @patch('evalml.pipelines.MulticlassClassificationPipeline.fit')
 def test_automl_allowed_pipelines_specified_allowed_pipelines_multi(mock_fit, mock_score, dummy_multiclass_pipeline_class, X_y_multi):
     X, y = X_y_multi
-    automl = AutoMLSearch(problem_type='multiclass', allowed_pipelines=[dummy_multiclass_pipeline_class], allowed_model_families=None)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='multiclass', allowed_pipelines=[dummy_multiclass_pipeline_class], allowed_model_families=None)
     expected_pipelines = [dummy_multiclass_pipeline_class]
     mock_score.return_value = {automl.objective.name: 1.0}
     assert automl.allowed_pipelines == expected_pipelines
     assert automl.allowed_model_families is None
 
-    automl.search(X, y)
+    automl.search()
     mock_fit.assert_called()
     mock_score.assert_called()
     assert automl.allowed_pipelines == expected_pipelines
@@ -468,12 +482,12 @@ def test_automl_allowed_pipelines_specified_allowed_pipelines_multi(mock_fit, mo
 @patch('evalml.pipelines.BinaryClassificationPipeline.fit')
 def test_automl_allowed_pipelines_specified_allowed_model_families_binary(mock_fit, mock_score, X_y_binary, assert_allowed_pipelines_equal_helper):
     X, y = X_y_binary
-    automl = AutoMLSearch(problem_type='binary', allowed_pipelines=None, allowed_model_families=[ModelFamily.RANDOM_FOREST])
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', allowed_pipelines=None, allowed_model_families=[ModelFamily.RANDOM_FOREST])
     mock_score.return_value = {automl.objective.name: 1.0}
     expected_pipelines = [make_pipeline(X, y, estimator, ProblemTypes.BINARY) for estimator in get_estimators(ProblemTypes.BINARY, model_families=[ModelFamily.RANDOM_FOREST])]
     assert automl.allowed_pipelines is None
 
-    automl.search(X, y)
+    automl.search()
     assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
     assert set(automl.allowed_model_families) == set([ModelFamily.RANDOM_FOREST])
     mock_fit.assert_called()
@@ -481,10 +495,10 @@ def test_automl_allowed_pipelines_specified_allowed_model_families_binary(mock_f
 
     mock_fit.reset_mock()
     mock_score.reset_mock()
-    automl = AutoMLSearch(problem_type='binary', allowed_pipelines=None, allowed_model_families=['random_forest'])
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', allowed_pipelines=None, allowed_model_families=['random_forest'])
     expected_pipelines = [make_pipeline(X, y, estimator, ProblemTypes.BINARY) for estimator in get_estimators(ProblemTypes.BINARY, model_families=[ModelFamily.RANDOM_FOREST])]
     assert automl.allowed_pipelines is None
-    automl.search(X, y)
+    automl.search()
     assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
     assert set(automl.allowed_model_families) == set([ModelFamily.RANDOM_FOREST])
     mock_fit.assert_called()
@@ -495,12 +509,12 @@ def test_automl_allowed_pipelines_specified_allowed_model_families_binary(mock_f
 @patch('evalml.pipelines.MulticlassClassificationPipeline.fit')
 def test_automl_allowed_pipelines_specified_allowed_model_families_multi(mock_fit, mock_score, X_y_multi, assert_allowed_pipelines_equal_helper):
     X, y = X_y_multi
-    automl = AutoMLSearch(problem_type='multiclass', allowed_pipelines=None, allowed_model_families=[ModelFamily.RANDOM_FOREST])
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='multiclass', allowed_pipelines=None, allowed_model_families=[ModelFamily.RANDOM_FOREST])
     mock_score.return_value = {automl.objective.name: 1.0}
     expected_pipelines = [make_pipeline(X, y, estimator, ProblemTypes.MULTICLASS) for estimator in get_estimators(ProblemTypes.MULTICLASS, model_families=[ModelFamily.RANDOM_FOREST])]
     assert automl.allowed_pipelines is None
 
-    automl.search(X, y)
+    automl.search()
     assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
     assert set(automl.allowed_model_families) == set([ModelFamily.RANDOM_FOREST])
     mock_fit.assert_called()
@@ -508,10 +522,10 @@ def test_automl_allowed_pipelines_specified_allowed_model_families_multi(mock_fi
 
     mock_fit.reset_mock()
     mock_score.reset_mock()
-    automl = AutoMLSearch(problem_type='multiclass', allowed_pipelines=None, allowed_model_families=['random_forest'])
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='multiclass', allowed_pipelines=None, allowed_model_families=['random_forest'])
     expected_pipelines = [make_pipeline(X, y, estimator, ProblemTypes.MULTICLASS) for estimator in get_estimators(ProblemTypes.MULTICLASS, model_families=[ModelFamily.RANDOM_FOREST])]
     assert automl.allowed_pipelines is None
-    automl.search(X, y)
+    automl.search()
     assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
     assert set(automl.allowed_model_families) == set([ModelFamily.RANDOM_FOREST])
     mock_fit.assert_called()
@@ -522,12 +536,12 @@ def test_automl_allowed_pipelines_specified_allowed_model_families_multi(mock_fi
 @patch('evalml.pipelines.BinaryClassificationPipeline.fit')
 def test_automl_allowed_pipelines_init_allowed_both_not_specified_binary(mock_fit, mock_score, X_y_binary, assert_allowed_pipelines_equal_helper):
     X, y = X_y_binary
-    automl = AutoMLSearch(problem_type='binary', allowed_pipelines=None, allowed_model_families=None)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', allowed_pipelines=None, allowed_model_families=None)
     mock_score.return_value = {automl.objective.name: 1.0}
     expected_pipelines = [make_pipeline(X, y, estimator, ProblemTypes.BINARY) for estimator in get_estimators(ProblemTypes.BINARY, model_families=None)]
     assert automl.allowed_pipelines is None
 
-    automl.search(X, y)
+    automl.search()
     assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
     assert set(automl.allowed_model_families) == set([p.model_family for p in expected_pipelines])
     mock_fit.assert_called()
@@ -538,12 +552,12 @@ def test_automl_allowed_pipelines_init_allowed_both_not_specified_binary(mock_fi
 @patch('evalml.pipelines.MulticlassClassificationPipeline.fit')
 def test_automl_allowed_pipelines_init_allowed_both_not_specified_multi(mock_fit, mock_score, X_y_multi, assert_allowed_pipelines_equal_helper):
     X, y = X_y_multi
-    automl = AutoMLSearch(problem_type='multiclass', allowed_pipelines=None, allowed_model_families=None)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='multiclass', allowed_pipelines=None, allowed_model_families=None)
     mock_score.return_value = {automl.objective.name: 1.0}
     expected_pipelines = [make_pipeline(X, y, estimator, ProblemTypes.MULTICLASS) for estimator in get_estimators(ProblemTypes.MULTICLASS, model_families=None)]
     assert automl.allowed_pipelines is None
 
-    automl.search(X, y)
+    automl.search()
     assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
     assert set(automl.allowed_model_families) == set([p.model_family for p in expected_pipelines])
     mock_fit.assert_called()
@@ -554,13 +568,13 @@ def test_automl_allowed_pipelines_init_allowed_both_not_specified_multi(mock_fit
 @patch('evalml.pipelines.BinaryClassificationPipeline.fit')
 def test_automl_allowed_pipelines_init_allowed_both_specified_binary(mock_fit, mock_score, dummy_binary_pipeline_class, X_y_binary, assert_allowed_pipelines_equal_helper):
     X, y = X_y_binary
-    automl = AutoMLSearch(problem_type='binary', allowed_pipelines=[dummy_binary_pipeline_class], allowed_model_families=[ModelFamily.RANDOM_FOREST])
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', allowed_pipelines=[dummy_binary_pipeline_class], allowed_model_families=[ModelFamily.RANDOM_FOREST])
     mock_score.return_value = {automl.objective.name: 1.0}
     expected_pipelines = [dummy_binary_pipeline_class]
     assert automl.allowed_pipelines == expected_pipelines
     assert set(automl.allowed_model_families) == set([ModelFamily.RANDOM_FOREST])
 
-    automl.search(X, y)
+    automl.search()
     assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
     assert set(automl.allowed_model_families) == set([p.model_family for p in expected_pipelines])
     mock_fit.assert_called()
@@ -571,13 +585,13 @@ def test_automl_allowed_pipelines_init_allowed_both_specified_binary(mock_fit, m
 @patch('evalml.pipelines.MulticlassClassificationPipeline.fit')
 def test_automl_allowed_pipelines_init_allowed_both_specified_multi(mock_fit, mock_score, dummy_multiclass_pipeline_class, X_y_multi, assert_allowed_pipelines_equal_helper):
     X, y = X_y_multi
-    automl = AutoMLSearch(problem_type='multiclass', allowed_pipelines=[dummy_multiclass_pipeline_class], allowed_model_families=[ModelFamily.RANDOM_FOREST])
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='multiclass', allowed_pipelines=[dummy_multiclass_pipeline_class], allowed_model_families=[ModelFamily.RANDOM_FOREST])
     mock_score.return_value = {automl.objective.name: 1.0}
     expected_pipelines = [dummy_multiclass_pipeline_class]
     assert automl.allowed_pipelines == expected_pipelines
     assert set(automl.allowed_model_families) == set([ModelFamily.RANDOM_FOREST])
 
-    automl.search(X, y)
+    automl.search()
     assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
     assert set(automl.allowed_model_families) == set([p.model_family for p in expected_pipelines])
     mock_fit.assert_called()
@@ -592,9 +606,9 @@ def test_automl_allowed_pipelines_search(mock_fit, mock_score, dummy_binary_pipe
 
     allowed_pipelines = [dummy_binary_pipeline_class]
     start_iteration_callback = MagicMock()
-    automl = AutoMLSearch(problem_type='binary', max_iterations=2, start_iteration_callback=start_iteration_callback,
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', max_iterations=2, start_iteration_callback=start_iteration_callback,
                           allowed_pipelines=allowed_pipelines)
-    automl.search(X, y)
+    automl.search()
 
     assert start_iteration_callback.call_count == 2
     assert start_iteration_callback.call_args_list[0][0][0] == ModeBaselineBinaryPipeline
@@ -612,5 +626,34 @@ def test_categorical_hyperparam(X_y_multi):
             }
         }
 
-    automl = AutoMLSearch(problem_type="multiclass", allowed_pipelines=[CustomPipeline])
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type="multiclass", allowed_pipelines=[CustomPipeline], n_jobs=1)
+    automl.search()
+
+
+def test_automl_binary_nonlinear_pipeline_search(nonlinear_binary_pipeline_class, X_y_binary):
+    X, y = X_y_binary
+
+    allowed_pipelines = [nonlinear_binary_pipeline_class]
+    start_iteration_callback = MagicMock()
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', max_iterations=2, start_iteration_callback=start_iteration_callback,
+                          allowed_pipelines=allowed_pipelines, n_jobs=1)
+    automl.search()
+
+    assert start_iteration_callback.call_count == 2
+    assert start_iteration_callback.call_args_list[0][0][0] == ModeBaselineBinaryPipeline
+    assert start_iteration_callback.call_args_list[1][0][0] == nonlinear_binary_pipeline_class
+
+
+def test_automl_multiclass_nonlinear_pipeline_search_more_iterations(nonlinear_multiclass_pipeline_class, X_y_multi):
+    X, y = X_y_multi
+
+    allowed_pipelines = [nonlinear_multiclass_pipeline_class]
+    start_iteration_callback = MagicMock()
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='multiclass', max_iterations=5, start_iteration_callback=start_iteration_callback,
+                          allowed_pipelines=allowed_pipelines, n_jobs=1)
+    automl.search()
+
+    assert start_iteration_callback.call_count == 5
+    assert start_iteration_callback.call_args_list[0][0][0] == ModeBaselineMulticlassPipeline
+    assert start_iteration_callback.call_args_list[1][0][0] == nonlinear_multiclass_pipeline_class
+    assert start_iteration_callback.call_args_list[4][0][0] == nonlinear_multiclass_pipeline_class
