@@ -17,30 +17,34 @@ from evalml.problem_types import ProblemTypes
 def test_init(X_y_regression):
     X, y = X_y_regression
 
-    automl = AutoMLSearch(problem_type='regression', objective="R2", max_iterations=3, n_jobs=4)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', objective="R2", max_iterations=3, n_jobs=1)
+    automl.search()
 
-    assert automl.n_jobs == 4
+    assert automl.n_jobs == 1
     assert isinstance(automl.rankings, pd.DataFrame)
     assert isinstance(automl.best_pipeline, PipelineBase)
+    automl.best_pipeline.predict(X)
 
     # test with dataframes
-    automl = AutoMLSearch(problem_type='regression', objective="R2", max_iterations=3, n_jobs=4)
-    automl.search(pd.DataFrame(X), pd.Series(y))
+    automl = AutoMLSearch(pd.DataFrame(X), pd.Series(y), problem_type='regression', objective="R2", max_iterations=3, n_jobs=1)
+    automl.search()
 
     assert isinstance(automl.rankings, pd.DataFrame)
     assert isinstance(automl.full_rankings, pd.DataFrame)
     assert isinstance(automl.best_pipeline, PipelineBase)
+    automl.best_pipeline.predict(X)
     assert isinstance(automl.get_pipeline(0), PipelineBase)
 
 
 def test_random_state(X_y_regression):
     X, y = X_y_regression
-    automl = AutoMLSearch(problem_type='regression', objective="R2", max_iterations=5, random_state=0)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', objective="R2", max_iterations=5, random_state=0,
+                          n_jobs=1)
+    automl.search()
 
-    automl_1 = AutoMLSearch(problem_type='regression', objective="R2", max_iterations=5, random_state=0)
-    automl_1.search(X, y)
+    automl_1 = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', objective="R2", max_iterations=5, random_state=0,
+                            n_jobs=1)
+    automl_1.search()
 
     # need to use assert_frame_equal as R2 could be different at the 10+ decimal
     assert pd.testing.assert_frame_equal(automl.rankings, automl_1.rankings) is None
@@ -48,8 +52,9 @@ def test_random_state(X_y_regression):
 
 def test_categorical_regression(X_y_categorical_regression):
     X, y = X_y_categorical_regression
-    automl = AutoMLSearch(problem_type='regression', objective="R2", max_iterations=5, random_state=0)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', objective="R2", max_iterations=5, random_state=0,
+                          n_jobs=1)
+    automl.search()
     assert not automl.rankings['score'].isnull().all()
 
 
@@ -68,20 +73,22 @@ def test_callback(X_y_regression):
         counts["add_result_callback"] += 1
 
     max_iterations = 3
-    automl = AutoMLSearch(problem_type='regression', objective="R2", max_iterations=max_iterations,
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', objective="R2", max_iterations=max_iterations,
                           start_iteration_callback=start_iteration_callback,
-                          add_result_callback=add_result_callback)
-    automl.search(X, y)
+                          add_result_callback=add_result_callback, n_jobs=1)
+    automl.search()
 
     assert counts["start_iteration_callback"] == max_iterations
     assert counts["add_result_callback"] == max_iterations
 
 
-def test_early_stopping(caplog, linear_regression_pipeline_class):
+def test_early_stopping(caplog, linear_regression_pipeline_class, X_y_regression):
+    X, y = X_y_regression
     tolerance = 0.005
     patience = 2
-    automl = AutoMLSearch(problem_type='regression', objective='mse', max_time='60 seconds',
-                          patience=patience, tolerance=tolerance, allowed_model_families=['linear_model'], random_state=0)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', objective='mse', max_time='60 seconds',
+                          patience=patience, tolerance=tolerance,
+                          allowed_model_families=['linear_model'], random_state=0, n_jobs=1)
 
     mock_results = {
         'search_order': [0, 1, 2],
@@ -103,7 +110,7 @@ def test_early_stopping(caplog, linear_regression_pipeline_class):
 def test_plot_disabled_missing_dependency(X_y_regression, has_minimal_dependencies):
     X, y = X_y_regression
 
-    automl = AutoMLSearch(problem_type='regression', max_iterations=3)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', max_iterations=3)
     if has_minimal_dependencies:
         with pytest.raises(AttributeError):
             automl.plot.search_iteration_plot
@@ -115,8 +122,8 @@ def test_plot_iterations_max_iterations(X_y_regression):
     go = pytest.importorskip('plotly.graph_objects', reason='Skipping plotting test because plotly not installed')
     X, y = X_y_regression
 
-    automl = AutoMLSearch(problem_type='regression', max_iterations=3)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', max_iterations=3, n_jobs=1)
+    automl.search()
     plot = automl.plot.search_iteration_plot()
     plot_data = plot.data[0]
     x = pd.Series(plot_data['x'])
@@ -133,8 +140,8 @@ def test_plot_iterations_max_time(X_y_regression):
     go = pytest.importorskip('plotly.graph_objects', reason='Skipping plotting test because plotly not installed')
     X, y = X_y_regression
 
-    automl = AutoMLSearch(problem_type='regression', max_time=10, random_state=1)
-    automl.search(X, y, show_iteration_plot=False)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', max_time=10, random_state=1, n_jobs=1)
+    automl.search(show_iteration_plot=False)
     plot = automl.plot.search_iteration_plot()
     plot_data = plot.data[0]
     x = pd.Series(plot_data['x'])
@@ -147,35 +154,36 @@ def test_plot_iterations_max_time(X_y_regression):
     assert len(y) > 0
 
 
-def test_log_metrics_only_passed_directly():
+def test_log_metrics_only_passed_directly(X_y_regression):
+    X, y = X_y_regression
     with pytest.raises(ObjectiveNotFoundError, match="RootMeanSquaredLogError is not a valid Objective!"):
-        AutoMLSearch(problem_type='regression', additional_objectives=['RootMeanSquaredLogError', 'MeanSquaredLogError'])
+        AutoMLSearch(X_train=X, y_train=y, problem_type='regression', additional_objectives=['RootMeanSquaredLogError', 'MeanSquaredLogError'])
 
-    ar = AutoMLSearch(problem_type='regression', additional_objectives=[RootMeanSquaredLogError(), MeanSquaredLogError()])
+    ar = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', additional_objectives=[RootMeanSquaredLogError(), MeanSquaredLogError()])
     assert ar.additional_objectives[0].name == 'Root Mean Squared Log Error'
     assert ar.additional_objectives[1].name == 'Mean Squared Log Error'
 
 
 def test_automl_allowed_pipelines_no_allowed_pipelines(X_y_regression):
     X, y = X_y_regression
-    automl = AutoMLSearch(problem_type='regression', allowed_pipelines=None, allowed_model_families=[])
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', allowed_pipelines=None, allowed_model_families=[])
     assert automl.allowed_pipelines is None
     with pytest.raises(ValueError, match="No allowed pipelines to search"):
-        automl.search(X, y)
+        automl.search()
 
 
 @patch('evalml.pipelines.RegressionPipeline.score')
 @patch('evalml.pipelines.RegressionPipeline.fit')
 def test_automl_allowed_pipelines_specified_allowed_pipelines(mock_fit, mock_score, dummy_regression_pipeline_class, X_y_regression):
     X, y = X_y_regression
-    automl = AutoMLSearch(problem_type='regression', allowed_pipelines=[dummy_regression_pipeline_class], allowed_model_families=None)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', allowed_pipelines=[dummy_regression_pipeline_class], allowed_model_families=None)
     mock_score.return_value = {automl.objective.name: 1.0}
     expected_pipelines = [dummy_regression_pipeline_class]
     mock_score.return_value = {automl.objective.name: 1.0}
     assert automl.allowed_pipelines == expected_pipelines
     assert automl.allowed_model_families is None
 
-    automl.search(X, y)
+    automl.search()
     mock_fit.assert_called()
     mock_score.assert_called()
     assert automl.allowed_pipelines == expected_pipelines
@@ -186,12 +194,12 @@ def test_automl_allowed_pipelines_specified_allowed_pipelines(mock_fit, mock_sco
 @patch('evalml.pipelines.RegressionPipeline.fit')
 def test_automl_allowed_pipelines_specified_allowed_model_families(mock_fit, mock_score, X_y_regression, assert_allowed_pipelines_equal_helper):
     X, y = X_y_regression
-    automl = AutoMLSearch(problem_type='regression', allowed_pipelines=None, allowed_model_families=[ModelFamily.RANDOM_FOREST])
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', allowed_pipelines=None, allowed_model_families=[ModelFamily.RANDOM_FOREST])
     mock_score.return_value = {automl.objective.name: 1.0}
     expected_pipelines = [make_pipeline(X, y, estimator, ProblemTypes.REGRESSION) for estimator in get_estimators(ProblemTypes.REGRESSION, model_families=[ModelFamily.RANDOM_FOREST])]
     assert automl.allowed_pipelines is None
 
-    automl.search(X, y)
+    automl.search()
     assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
     assert set(automl.allowed_model_families) == set([ModelFamily.RANDOM_FOREST])
     mock_fit.assert_called()
@@ -199,11 +207,11 @@ def test_automl_allowed_pipelines_specified_allowed_model_families(mock_fit, moc
 
     mock_fit.reset_mock()
     mock_score.reset_mock()
-    automl = AutoMLSearch(problem_type='regression', allowed_pipelines=None, allowed_model_families=['random_forest'])
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', allowed_pipelines=None, allowed_model_families=['random_forest'])
     expected_pipelines = [make_pipeline(X, y, estimator, ProblemTypes.REGRESSION) for estimator in get_estimators(ProblemTypes.REGRESSION, model_families=[ModelFamily.RANDOM_FOREST])]
     assert automl.allowed_pipelines is None
 
-    automl.search(X, y)
+    automl.search()
     assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
     assert set(automl.allowed_model_families) == set([ModelFamily.RANDOM_FOREST])
     mock_fit.assert_called()
@@ -214,12 +222,12 @@ def test_automl_allowed_pipelines_specified_allowed_model_families(mock_fit, moc
 @patch('evalml.pipelines.RegressionPipeline.fit')
 def test_automl_allowed_pipelines_init_allowed_both_not_specified(mock_fit, mock_score, X_y_regression, assert_allowed_pipelines_equal_helper):
     X, y = X_y_regression
-    automl = AutoMLSearch(problem_type='regression', allowed_pipelines=None, allowed_model_families=None)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', allowed_pipelines=None, allowed_model_families=None)
     mock_score.return_value = {automl.objective.name: 1.0}
     expected_pipelines = [make_pipeline(X, y, estimator, ProblemTypes.REGRESSION) for estimator in get_estimators(ProblemTypes.REGRESSION, model_families=None)]
     assert automl.allowed_pipelines is None
 
-    automl.search(X, y)
+    automl.search()
     assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
     assert set(automl.allowed_model_families) == set([p.model_family for p in expected_pipelines])
     mock_fit.assert_called()
@@ -230,13 +238,13 @@ def test_automl_allowed_pipelines_init_allowed_both_not_specified(mock_fit, mock
 @patch('evalml.pipelines.RegressionPipeline.fit')
 def test_automl_allowed_pipelines_init_allowed_both_specified(mock_fit, mock_score, dummy_regression_pipeline_class, X_y_regression, assert_allowed_pipelines_equal_helper):
     X, y = X_y_regression
-    automl = AutoMLSearch(problem_type='regression', allowed_pipelines=[dummy_regression_pipeline_class], allowed_model_families=[ModelFamily.RANDOM_FOREST])
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', allowed_pipelines=[dummy_regression_pipeline_class], allowed_model_families=[ModelFamily.RANDOM_FOREST])
     mock_score.return_value = {automl.objective.name: 1.0}
     expected_pipelines = [dummy_regression_pipeline_class]
     assert automl.allowed_pipelines == expected_pipelines
     assert set(automl.allowed_model_families) == set([ModelFamily.RANDOM_FOREST])
 
-    automl.search(X, y)
+    automl.search()
     assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
     assert set(automl.allowed_model_families) == set([p.model_family for p in expected_pipelines])
     mock_fit.assert_called()
@@ -251,10 +259,24 @@ def test_automl_allowed_pipelines_search(mock_fit, mock_score, dummy_regression_
 
     allowed_pipelines = [dummy_regression_pipeline_class]
     start_iteration_callback = MagicMock()
-    automl = AutoMLSearch(problem_type='regression', max_iterations=2, start_iteration_callback=start_iteration_callback,
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', max_iterations=2, start_iteration_callback=start_iteration_callback,
                           allowed_pipelines=allowed_pipelines)
-    automl.search(X, y)
+    automl.search()
 
     assert start_iteration_callback.call_count == 2
     assert start_iteration_callback.call_args_list[0][0][0] == MeanBaselineRegressionPipeline
     assert start_iteration_callback.call_args_list[1][0][0] == dummy_regression_pipeline_class
+
+
+def test_automl_regression_nonlinear_pipeline_search(nonlinear_regression_pipeline_class, X_y_regression):
+    X, y = X_y_regression
+
+    allowed_pipelines = [nonlinear_regression_pipeline_class]
+    start_iteration_callback = MagicMock()
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', max_iterations=2, start_iteration_callback=start_iteration_callback,
+                          allowed_pipelines=allowed_pipelines, n_jobs=1)
+    automl.search()
+
+    assert start_iteration_callback.call_count == 2
+    assert start_iteration_callback.call_args_list[0][0][0] == MeanBaselineRegressionPipeline
+    assert start_iteration_callback.call_args_list[1][0][0] == nonlinear_regression_pipeline_class
