@@ -32,8 +32,8 @@ def test_fit_predict(X_y_regression):
 def test_feature_importance(X_y_regression):
     X, y = X_y_regression
 
-    clf = ExtraTreesRegressor()
-    sk_clf = SKExtraTreesRegressor(max_depth=6, random_state=0)
+    clf = ExtraTreesRegressor(n_jobs=1)
+    sk_clf = SKExtraTreesRegressor(max_depth=6, random_state=0, n_jobs=1)
     sk_clf.fit(X, y)
     sk_feature_importance = sk_clf.feature_importances_
 
