@@ -4,6 +4,7 @@ from unittest.mock import MagicMock, patch
 import numpy as np
 import pandas as pd
 import pytest
+import woodwork as ww
 
 from evalml.exceptions import PipelineScoreError
 from evalml.model_understanding.prediction_explanations.explainers import (
@@ -22,13 +23,13 @@ def compare_two_tables(table_1, table_2):
         assert row.strip().split() == row_answer.strip().split()
 
 
-test_features = [5, [1], np.ones((1, 15)), pd.DataFrame({"a": [1, 2, 3], "b": [1, 2, 3]}).iloc[0],
+test_features = [[1], np.ones((15, 1)), pd.DataFrame({"a": [1, 2, 3], "b": [1, 2, 3]}).iloc[0],
                  pd.DataFrame({"a": [1, 2, 3], "b": [4, 5, 6]}), pd.DataFrame()]
 
 
 @pytest.mark.parametrize("test_features", test_features)
 def test_explain_prediction_value_error(test_features):
-    with pytest.raises(ValueError, match="features must be stored in a dataframe of one row."):
+    with pytest.raises(ValueError, match="features must be stored in a dataframe or datatable with exactly one row."):
         explain_prediction(None, input_features=test_features, training_data=None)
 
 
@@ -102,7 +103,7 @@ explain_prediction_multiclass_dict_answer = {
 }
 
 
-@pytest.mark.parametrize("problem_type,output_format,shap_values,normalized_shap_values,answer",
+@pytest.mark.parametrize("problem_type, output_format, shap_values, normalized_shap_values, answer",
                          [(ProblemTypes.REGRESSION,
                            "text",
                            {"a": [1], "b": [-2.1], "c": [-0.25], "d": [2.3]},
@@ -139,11 +140,13 @@ explain_prediction_multiclass_dict_answer = {
                             {"a": [0.03], "b": [0.02], "c": [-0.42], "d": [-0.47]}],
                            explain_prediction_multiclass_dict_answer)
                           ])
+@pytest.mark.parametrize("input_type", ["pd", "ww"])
 @patch("evalml.model_understanding.prediction_explanations._user_interface._compute_shap_values")
 @patch("evalml.model_understanding.prediction_explanations._user_interface._normalize_shap_values")
 def test_explain_prediction(mock_normalize_shap_values,
                             mock_compute_shap_values,
-                            problem_type, output_format, shap_values, normalized_shap_values, answer):
+                            problem_type, output_format, shap_values, normalized_shap_values, answer,
+                            input_type):
     mock_compute_shap_values.return_value = shap_values
     mock_normalize_shap_values.return_value = normalized_shap_values
     pipeline = MagicMock()
@@ -153,7 +156,11 @@ def test_explain_prediction(mock_normalize_shap_values,
     # By the time we call transform, we are looking at only one row of the input data.
     pipeline.compute_estimator_features.return_value = pd.DataFrame({"a": [10], "b": [20], "c": [30], "d": [40]})
     features = pd.DataFrame({"a": [1], "b": [2]})
-    table = explain_prediction(pipeline, features, output_format=output_format, top_k=2)
+    training_data = pd.DataFrame()
+    if input_type == "ww":
+        features = ww.DataTable(features)
+        training_data = ww.DataTable(training_data)
+    table = explain_prediction(pipeline, features, output_format=output_format, top_k=2, training_data=training_data)
 
     if isinstance(table, str):
         compare_two_tables(table.splitlines(), answer)
@@ -169,9 +176,8 @@ def test_error_metrics():
                                    pd.Series([-np.log(0.9), -np.log(0.2)]))
 
 
-input_features_and_y_true = [([1], None, "^Input features must be a dataframe with more than 10 rows!"),
-                             (pd.DataFrame({"a": [1]}), None, "^Input features must be a dataframe with more than 10 rows!"),
-                             (pd.DataFrame({"a": range(15)}), [1], "^Parameter y_true must be a pd.Series."),
+input_features_and_y_true = [([[1]], pd.Series([1]), "^Input features must be a dataframe with more than 10 rows!"),
+                             (pd.DataFrame({"a": [1]}), pd.Series([1]), "^Input features must be a dataframe with more than 10 rows!"),
                              (pd.DataFrame({"a": range(15)}), pd.Series(range(12)), "^Parameters y_true and input_features must have the same number of data points.")
                              ]
 
@@ -194,23 +200,22 @@ def test_explain_predictions_raises_pipeline_score_error():
         explain_predictions_best_worst(pipeline, pd.DataFrame({"a": range(15)}), pd.Series(range(15)))
 
 
-@pytest.mark.parametrize("input_features", [1, [1], "foo", pd.DataFrame()])
-def test_explain_predictions_value_errors(input_features):
+def test_explain_predictions_value_errors():
     with pytest.raises(ValueError, match="Parameter input_features must be a non-empty dataframe."):
-        explain_predictions(None, input_features)
+        explain_predictions(None, pd.DataFrame())
 
 
 def test_output_format_checked():
-    input_features, y_true = pd.DataFrame({"a": range(15)}), pd.Series(range(15))
+    input_features, y_true = pd.DataFrame(data=[range(15)]), pd.Series(range(15))
     with pytest.raises(ValueError, match="Parameter output_format must be either text or dict. Received bar"):
         explain_predictions(None, input_features, output_format="bar")
-
-    with pytest.raises(ValueError, match="Parameter output_format must be either text or dict. Received foo"):
-        explain_predictions_best_worst(None, input_features, y_true=y_true, output_format="foo")
-
     with pytest.raises(ValueError, match="Parameter output_format must be either text or dict. Received xml"):
         explain_prediction(None, input_features=input_features, training_data=None, output_format="xml")
 
+    input_features, y_true = pd.DataFrame(data=range(15)), pd.Series(range(15))
+    with pytest.raises(ValueError, match="Parameter output_format must be either text or dict. Received foo"):
+        explain_predictions_best_worst(None, input_features, y_true=y_true, output_format="foo")
+
 
 regression_best_worst_answer = """Test Pipeline Name
 
@@ -596,17 +601,15 @@ def test_json_serialization(problem_type, X_y_regression, linear_regression_pipe
     if problem_type == problem_type.REGRESSION:
         X, y = X_y_regression
         y = pd.Series(y)
-        pipeline_class = linear_regression_pipeline_class
+        pipeline = linear_regression_pipeline_class(parameters={"Linear Regressor": {"n_jobs": 1}})
     elif problem_type == problem_type.BINARY:
         X, y = X_y_binary
         y = pd.Series(y).astype("str")
-        pipeline_class = logistic_regression_binary_pipeline_class
+        pipeline = logistic_regression_binary_pipeline_class(parameters={"Logistic Regression Classifier": {"n_jobs": 1}})
     else:
         X, y = X_y_multi
         y = pd.Series(y).astype("str")
-        pipeline_class = logistic_regression_multiclass_pipeline_class
-
-    pipeline = pipeline_class({})
+        pipeline = logistic_regression_multiclass_pipeline_class(parameters={"Logistic Regression Classifier": {"n_jobs": 1}})
 
     pipeline.fit(X, y)
 
