@@ -26,8 +26,8 @@ def test_cbm_objective_automl(optimize_thresholds, X_y_binary):
     X, y = X_y_binary
     cbm = CostBenefitMatrix(true_positive=10, true_negative=-1,
                             false_positive=-7, false_negative=-2)
-    automl = AutoMLSearch(problem_type='binary', objective=cbm, max_iterations=2, optimize_thresholds=optimize_thresholds)
-    automl.search(X, y)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='binary', objective=cbm, max_iterations=2, optimize_thresholds=optimize_thresholds)
+    automl.search()
 
     pipeline = automl.best_pipeline
     pipeline.fit(X, y)
@@ -37,9 +37,12 @@ def test_cbm_objective_automl(optimize_thresholds, X_y_binary):
     assert not np.isnan(list(pipeline.predict(X, cbm))).any()
 
 
-def test_cbm_objective_function():
+@pytest.mark.parametrize("data_type", ['ww', 'pd'])
+def test_cbm_objective_function(data_type, make_data_type):
     y_true = pd.Series([0, 0, 0, 1, 1, 1, 1, 1, 1, 1])
     y_predicted = pd.Series([0, 0, 1, 0, 0, 0, 0, 1, 1, 1])
+    y_true = make_data_type(data_type, y_true)
+    y_predicted = make_data_type(data_type, y_predicted)
     cbm = CostBenefitMatrix(true_positive=10, true_negative=-1,
                             false_positive=-7, false_negative=-2)
     assert np.isclose(cbm.objective_function(y_true, y_predicted), ((3 * 10) + (-1 * 2) + (1 * -7) + (4 * -2)) / 10)
