@@ -2,7 +2,6 @@ from itertools import product
 
 import pandas as pd
 import pytest
-import woodwork as ww
 
 from evalml.demos import load_breast_cancer, load_wine
 
@@ -12,11 +11,11 @@ def test_new_unique_targets_in_score(X_y_binary, logistic_regression_binary_pipe
                                      X_y_multi, logistic_regression_multiclass_pipeline_class, problem_type):
     if problem_type == "binary":
         X, y = X_y_binary
-        pipeline = logistic_regression_binary_pipeline_class(parameters={})
+        pipeline = logistic_regression_binary_pipeline_class(parameters={"Logistic Regression Classifier": {"n_jobs": 1}})
         objective = 'Log Loss Binary'
     elif problem_type == "multi":
         X, y = X_y_multi
-        pipeline = logistic_regression_multiclass_pipeline_class(parameters={})
+        pipeline = logistic_regression_multiclass_pipeline_class(parameters={"Logistic Regression Classifier": {"n_jobs": 1}})
         objective = 'Log Loss Multiclass'
     pipeline.fit(X, y)
     with pytest.raises(ValueError, match="y contains previously unseen labels"):
@@ -27,16 +26,16 @@ def test_new_unique_targets_in_score(X_y_binary, logistic_regression_binary_pipe
 def test_pipeline_has_classes_property(logistic_regression_binary_pipeline_class,
                                        logistic_regression_multiclass_pipeline_class, problem_type, use_ints):
     if problem_type == "binary":
-        X, y = load_breast_cancer()
-        pipeline = logistic_regression_binary_pipeline_class(parameters={})
+        X, y = load_breast_cancer(return_pandas=True)
+        pipeline = logistic_regression_binary_pipeline_class(parameters={"Logistic Regression Classifier": {"n_jobs": 1}})
         if use_ints:
             y = y.map({'malignant': 0, 'benign': 1})
             answer = [0, 1]
         else:
             answer = ["benign", "malignant"]
     elif problem_type == "multi":
-        X, y = load_wine()
-        pipeline = logistic_regression_multiclass_pipeline_class(parameters={})
+        X, y = load_wine(return_pandas=True)
+        pipeline = logistic_regression_multiclass_pipeline_class(parameters={"Logistic Regression Classifier": {"n_jobs": 1}})
         if use_ints:
             y = y.map({"class_0": 0, "class_1": 1, "class_2": 2})
             answer = [0, 1, 2]
@@ -52,9 +51,7 @@ def test_pipeline_has_classes_property(logistic_regression_binary_pipeline_class
 
 def test_woodwork_classification_pipeline(logistic_regression_binary_pipeline_class):
     X, y = load_breast_cancer()
-    X = ww.DataTable(X)
-    y = ww.DataColumn(y)
-    mock_pipeline = logistic_regression_binary_pipeline_class(parameters={})
+    mock_pipeline = logistic_regression_binary_pipeline_class(parameters={"Logistic Regression Classifier": {"n_jobs": 1}})
     mock_pipeline.fit(X, y)
     assert not pd.isnull(mock_pipeline.predict(X)).any()
     assert not pd.isnull(mock_pipeline.predict_proba(X)).any().any()
